drop _all
log using cont2d4,replace
*
* This STATA program compares exchange rate crises with periods of tranquility
* with a RF bivariate probit technique.  Lags of macroeconomic and political
* variables are controls, and the test is for the significance of crises in
* other countries, both as a solo variable and interacted with the controls.
*
* A 1.5 standard-deviation threshold with a 1-quarter window is used for
* crisis identification.  Germany is the center country throughout.  A two-
* quarter window is used around the regressands.  Two lags for regressors are
* used.
*
* This is a perturbation of CONT2d which weights crises according to macro-
* similarity, and then uses factor analysis to combine the measures.  Then a
* horse-race between unweighted, trade-weighted, and macro-weighted contagion
* measures is run.   It differs from CONT2d in that it is more user-friendly,
* designed for table construction.
*
set more 1
set matsiz 200
set maxobs 4000
*
* Read in the weights
*
infile using \res\erw\data\weights
drop if ifscode==134
replace ifscode=126 if ifscode==124
g date10=date*10
compress
sort ifscode date10
save crap,replace
drop _all
*
* Bring in the data and drop countries without exchange regime data
*
use \res\deluge\data\datav8
drop if country=="."
*
* Drop Germany (the center country), Iceland and some other countries without
* MERM weights
*
replace ifscode=126 if ifscode==124
drop if ifscode==134
drop if ifscode==176
drop if ifscode==181
drop if ifscode==186
drop if ifscode==188
drop if ifscode==199
*
* Merge the data sets
*
g date10=date*10
compress
sort ifscode date10
merge ifscode date10 using crap
tab _merge
drop if _merge==2
drop _merge
drop date10
*
* Convert money into dollars
*
g m1dol=ifs34/ifsrf
g gm1dol=gifs34/gifsrf
*
* Percentage change in reserves, less percentage change in M1
*
g dlres=(log(ifs1ld)-log(ifs1ld[_n-1]))-(log(m1dol)-log(m1dol[_n-1])) if ifscode==ifscode[_n-1]
g gdlres=(log(gifs1ld)-log(gifs1ld[_n-1]))-(log(gm1dol)-log(gm1dol[_n-1])) if ifscode==ifscode[_n-1]
*
* Differential between domestic and German value
*
g dlr=dlres-gdlres
*
* Percentage change in DM exchange rate
*
g dlpdm=log(ifsrf/gifsrf)-log(ifsrf[_n-1]/gifsrf[_n-1]) if ifscode==ifscode[_n-1]
*
* Domestic-German Interest Differential, scaled
*
g idom=ifs60b
replace idom=ifs60 if idom==.
g idiff=(idom/400.)-(gifs60b/400.)
g didiff=idiff-idiff[_n-1] if ifscode==ifscode[_n-1]
*
* Descriptive Statistics
*
quietly sum dlr
g stdr=_result(4)^.5
quietly sum dlpdm
g stde=_result(4)^.5
quietly sum didiff
g stdi=_result(4)^.5
*
* Create the aggregate measure from changes in reserves, interest rates, and
* exchange rates.  A positive shock marks an attack, which can be countered by
* a) increasing e (deval'n); or defence via b) increased i or; c) lowered res.
*
list stdr stde stdi in 1/1
g gr=((stdr/stde)*dlpdm)+((stdr/stdi)*(didiff))-(dlr)
*
* Some descriptive statistics on exchange market pressure
*
quietly sum gr
g avggr=_result(3)
g stdgr=_result(4)^.5
*
* Generate the binary exchange market pressure variable (regressand)
*
* The default is missing
*
g byte crisis=.
*
* Girton-Roper outliers mark crises
*
replace crisis=1 if gr>(avggr+(1.5*stdgr))&gr~=.
replace crisis=0 if gr<=(avggr+(1.5*stdgr))&gr~=.

replace crisis=. if (crisis[_n-1]==1)&(ifscode==ifscode[_n-1])
replace crisis=. if (crisis[_n-1]==0)&(ifscode==ifscode[_n-1])

tab crisis
list ifscode date if crisis==1
*
* Create current non-country-specific attacks
*
g date10=date*10
compress

sort date ifscode
g byte crisiso=0

quietly replace crisiso=1 if crisis[_n-1]==1&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly replace crisiso=1 if crisis[_n-2]==1&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly replace crisiso=1 if crisis[_n-3]==1&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly replace crisiso=1 if crisis[_n-4]==1&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly replace crisiso=1 if crisis[_n-5]==1&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly replace crisiso=1 if crisis[_n-6]==1&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly replace crisiso=1 if crisis[_n-7]==1&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly replace crisiso=1 if crisis[_n-8]==1&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly replace crisiso=1 if crisis[_n-9]==1&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly replace crisiso=1 if crisis[_n-10]==1&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly replace crisiso=1 if crisis[_n-11]==1&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly replace crisiso=1 if crisis[_n-12]==1&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly replace crisiso=1 if crisis[_n-13]==1&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly replace crisiso=1 if crisis[_n-14]==1&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly replace crisiso=1 if crisis[_n-15]==1&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly replace crisiso=1 if crisis[_n-16]==1&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly replace crisiso=1 if crisis[_n-17]==1&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly replace crisiso=1 if crisis[_n-18]==1&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly replace crisiso=1 if crisis[_n-19]==1&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly replace crisiso=1 if crisis[_n-20]==1&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly replace crisiso=1 if crisis[_n-21]==1&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])
quietly replace crisiso=1 if crisis[_n-22]==1&(ifscode~=ifscode[_n-22]&date10==date10[_n-22])
quietly replace crisiso=1 if crisis[_n-23]==1&(ifscode~=ifscode[_n-23]&date10==date10[_n-23])
quietly replace crisiso=1 if crisis[_n-24]==1&(ifscode~=ifscode[_n-24]&date10==date10[_n-24])

quietly replace crisiso=1 if crisis[_n+1]==1&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly replace crisiso=1 if crisis[_n+2]==1&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly replace crisiso=1 if crisis[_n+3]==1&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly replace crisiso=1 if crisis[_n+4]==1&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly replace crisiso=1 if crisis[_n+5]==1&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly replace crisiso=1 if crisis[_n+6]==1&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly replace crisiso=1 if crisis[_n+7]==1&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly replace crisiso=1 if crisis[_n+8]==1&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly replace crisiso=1 if crisis[_n+9]==1&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly replace crisiso=1 if crisis[_n+10]==1&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly replace crisiso=1 if crisis[_n+11]==1&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly replace crisiso=1 if crisis[_n+12]==1&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly replace crisiso=1 if crisis[_n+13]==1&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly replace crisiso=1 if crisis[_n+14]==1&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly replace crisiso=1 if crisis[_n+15]==1&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly replace crisiso=1 if crisis[_n+16]==1&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly replace crisiso=1 if crisis[_n+17]==1&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly replace crisiso=1 if crisis[_n+18]==1&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly replace crisiso=1 if crisis[_n+19]==1&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly replace crisiso=1 if crisis[_n+20]==1&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly replace crisiso=1 if crisis[_n+21]==1&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])
quietly replace crisiso=1 if crisis[_n+22]==1&(ifscode~=ifscode[_n+22]&date10==date10[_n+22])
quietly replace crisiso=1 if crisis[_n+23]==1&(ifscode~=ifscode[_n+23]&date10==date10[_n+23])
quietly replace crisiso=1 if crisis[_n+24]==1&(ifscode~=ifscode[_n+24]&date10==date10[_n+24])
*
* Create current non-country-specific attacks
*
sort date ifscode

g c193=0

replace c193=wt193 if (crisis[_n-1]==1&ifscode[_n-1]==193)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c193=wt193 if (crisis[_n-2]==1&ifscode[_n-2]==193)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c193=wt193 if (crisis[_n-3]==1&ifscode[_n-3]==193)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c193=wt193 if (crisis[_n-4]==1&ifscode[_n-4]==193)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c193=wt193 if (crisis[_n-5]==1&ifscode[_n-5]==193)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c193=wt193 if (crisis[_n-6]==1&ifscode[_n-6]==193)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c193=wt193 if (crisis[_n-7]==1&ifscode[_n-7]==193)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c193=wt193 if (crisis[_n-8]==1&ifscode[_n-8]==193)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c193=wt193 if (crisis[_n-9]==1&ifscode[_n-9]==193)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c193=wt193 if (crisis[_n-10]==1&ifscode[_n-10]==193)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c193=wt193 if (crisis[_n-11]==1&ifscode[_n-11]==193)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c193=wt193 if (crisis[_n-12]==1&ifscode[_n-12]==193)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c193=wt193 if (crisis[_n-13]==1&ifscode[_n-13]==193)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c193=wt193 if (crisis[_n-14]==1&ifscode[_n-14]==193)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c193=wt193 if (crisis[_n-15]==1&ifscode[_n-15]==193)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c193=wt193 if (crisis[_n-16]==1&ifscode[_n-16]==193)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c193=wt193 if (crisis[_n-17]==1&ifscode[_n-17]==193)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c193=wt193 if (crisis[_n-18]==1&ifscode[_n-18]==193)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c193=wt193 if (crisis[_n-19]==1&ifscode[_n-19]==193)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c193=wt193 if (crisis[_n-20]==1&ifscode[_n-20]==193)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c193=wt193 if (crisis[_n-21]==1&ifscode[_n-21]==193)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c193=wt193 if (crisis[_n+1]==1&ifscode[_n+1]==193)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c193=wt193 if (crisis[_n+2]==1&ifscode[_n+2]==193)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c193=wt193 if (crisis[_n+3]==1&ifscode[_n+3]==193)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c193=wt193 if (crisis[_n+4]==1&ifscode[_n+4]==193)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c193=wt193 if (crisis[_n+5]==1&ifscode[_n+5]==193)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c193=wt193 if (crisis[_n+6]==1&ifscode[_n+6]==193)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c193=wt193 if (crisis[_n+7]==1&ifscode[_n+7]==193)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c193=wt193 if (crisis[_n+8]==1&ifscode[_n+8]==193)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c193=wt193 if (crisis[_n+9]==1&ifscode[_n+9]==193)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c193=wt193 if (crisis[_n+10]==1&ifscode[_n+10]==193)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c193=wt193 if (crisis[_n+11]==1&ifscode[_n+11]==193)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c193=wt193 if (crisis[_n+12]==1&ifscode[_n+12]==193)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c193=wt193 if (crisis[_n+13]==1&ifscode[_n+13]==193)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c193=wt193 if (crisis[_n+14]==1&ifscode[_n+14]==193)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c193=wt193 if (crisis[_n+15]==1&ifscode[_n+15]==193)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c193=wt193 if (crisis[_n+16]==1&ifscode[_n+16]==193)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c193=wt193 if (crisis[_n+17]==1&ifscode[_n+17]==193)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c193=wt193 if (crisis[_n+18]==1&ifscode[_n+18]==193)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c193=wt193 if (crisis[_n+19]==1&ifscode[_n+19]==193)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c193=wt193 if (crisis[_n+20]==1&ifscode[_n+20]==193)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c193=wt193 if (crisis[_n+21]==1&ifscode[_n+21]==193)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c122=0

replace c122=wt122 if (crisis[_n-1]==1&ifscode[_n-1]==122)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c122=wt122 if (crisis[_n-2]==1&ifscode[_n-2]==122)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c122=wt122 if (crisis[_n-3]==1&ifscode[_n-3]==122)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c122=wt122 if (crisis[_n-4]==1&ifscode[_n-4]==122)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c122=wt122 if (crisis[_n-5]==1&ifscode[_n-5]==122)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c122=wt122 if (crisis[_n-6]==1&ifscode[_n-6]==122)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c122=wt122 if (crisis[_n-7]==1&ifscode[_n-7]==122)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c122=wt122 if (crisis[_n-8]==1&ifscode[_n-8]==122)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c122=wt122 if (crisis[_n-9]==1&ifscode[_n-9]==122)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c122=wt122 if (crisis[_n-10]==1&ifscode[_n-10]==122)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c122=wt122 if (crisis[_n-11]==1&ifscode[_n-11]==122)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c122=wt122 if (crisis[_n-12]==1&ifscode[_n-12]==122)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c122=wt122 if (crisis[_n-13]==1&ifscode[_n-13]==122)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c122=wt122 if (crisis[_n-14]==1&ifscode[_n-14]==122)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c122=wt122 if (crisis[_n-15]==1&ifscode[_n-15]==122)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c122=wt122 if (crisis[_n-16]==1&ifscode[_n-16]==122)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c122=wt122 if (crisis[_n-17]==1&ifscode[_n-17]==122)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c122=wt122 if (crisis[_n-18]==1&ifscode[_n-18]==122)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c122=wt122 if (crisis[_n-19]==1&ifscode[_n-19]==122)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c122=wt122 if (crisis[_n-20]==1&ifscode[_n-20]==122)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c122=wt122 if (crisis[_n-21]==1&ifscode[_n-21]==122)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c122=wt122 if (crisis[_n+1]==1&ifscode[_n+1]==122)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c122=wt122 if (crisis[_n+2]==1&ifscode[_n+2]==122)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c122=wt122 if (crisis[_n+3]==1&ifscode[_n+3]==122)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c122=wt122 if (crisis[_n+4]==1&ifscode[_n+4]==122)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c122=wt122 if (crisis[_n+5]==1&ifscode[_n+5]==122)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c122=wt122 if (crisis[_n+6]==1&ifscode[_n+6]==122)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c122=wt122 if (crisis[_n+7]==1&ifscode[_n+7]==122)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c122=wt122 if (crisis[_n+8]==1&ifscode[_n+8]==122)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c122=wt122 if (crisis[_n+9]==1&ifscode[_n+9]==122)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c122=wt122 if (crisis[_n+10]==1&ifscode[_n+10]==122)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c122=wt122 if (crisis[_n+11]==1&ifscode[_n+11]==122)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c122=wt122 if (crisis[_n+12]==1&ifscode[_n+12]==122)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c122=wt122 if (crisis[_n+13]==1&ifscode[_n+13]==122)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c122=wt122 if (crisis[_n+14]==1&ifscode[_n+14]==122)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c122=wt122 if (crisis[_n+15]==1&ifscode[_n+15]==122)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c122=wt122 if (crisis[_n+16]==1&ifscode[_n+16]==122)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c122=wt122 if (crisis[_n+17]==1&ifscode[_n+17]==122)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c122=wt122 if (crisis[_n+18]==1&ifscode[_n+18]==122)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c122=wt122 if (crisis[_n+19]==1&ifscode[_n+19]==122)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c122=wt122 if (crisis[_n+20]==1&ifscode[_n+20]==122)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c122=wt122 if (crisis[_n+21]==1&ifscode[_n+21]==122)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c126=0

replace c126=wt126 if (crisis[_n-1]==1&ifscode[_n-1]==126)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c126=wt126 if (crisis[_n-2]==1&ifscode[_n-2]==126)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c126=wt126 if (crisis[_n-3]==1&ifscode[_n-3]==126)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c126=wt126 if (crisis[_n-4]==1&ifscode[_n-4]==126)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c126=wt126 if (crisis[_n-5]==1&ifscode[_n-5]==126)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c126=wt126 if (crisis[_n-6]==1&ifscode[_n-6]==126)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c126=wt126 if (crisis[_n-7]==1&ifscode[_n-7]==126)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c126=wt126 if (crisis[_n-8]==1&ifscode[_n-8]==126)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c126=wt126 if (crisis[_n-9]==1&ifscode[_n-9]==126)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c126=wt126 if (crisis[_n-10]==1&ifscode[_n-10]==126)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c126=wt126 if (crisis[_n-11]==1&ifscode[_n-11]==126)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c126=wt126 if (crisis[_n-12]==1&ifscode[_n-12]==126)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c126=wt126 if (crisis[_n-13]==1&ifscode[_n-13]==126)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c126=wt126 if (crisis[_n-14]==1&ifscode[_n-14]==126)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c126=wt126 if (crisis[_n-15]==1&ifscode[_n-15]==126)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c126=wt126 if (crisis[_n-16]==1&ifscode[_n-16]==126)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c126=wt126 if (crisis[_n-17]==1&ifscode[_n-17]==126)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c126=wt126 if (crisis[_n-18]==1&ifscode[_n-18]==126)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c126=wt126 if (crisis[_n-19]==1&ifscode[_n-19]==126)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c126=wt126 if (crisis[_n-20]==1&ifscode[_n-20]==126)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c126=wt126 if (crisis[_n-21]==1&ifscode[_n-21]==126)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c126=wt126 if (crisis[_n+1]==1&ifscode[_n+1]==126)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c126=wt126 if (crisis[_n+2]==1&ifscode[_n+2]==126)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c126=wt126 if (crisis[_n+3]==1&ifscode[_n+3]==126)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c126=wt126 if (crisis[_n+4]==1&ifscode[_n+4]==126)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c126=wt126 if (crisis[_n+5]==1&ifscode[_n+5]==126)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c126=wt126 if (crisis[_n+6]==1&ifscode[_n+6]==126)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c126=wt126 if (crisis[_n+7]==1&ifscode[_n+7]==126)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c126=wt126 if (crisis[_n+8]==1&ifscode[_n+8]==126)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c126=wt126 if (crisis[_n+9]==1&ifscode[_n+9]==126)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c126=wt126 if (crisis[_n+10]==1&ifscode[_n+10]==126)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c126=wt126 if (crisis[_n+11]==1&ifscode[_n+11]==126)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c126=wt126 if (crisis[_n+12]==1&ifscode[_n+12]==126)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c126=wt126 if (crisis[_n+13]==1&ifscode[_n+13]==126)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c126=wt126 if (crisis[_n+14]==1&ifscode[_n+14]==126)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c126=wt126 if (crisis[_n+15]==1&ifscode[_n+15]==126)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c126=wt126 if (crisis[_n+16]==1&ifscode[_n+16]==126)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c126=wt126 if (crisis[_n+17]==1&ifscode[_n+17]==126)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c126=wt126 if (crisis[_n+18]==1&ifscode[_n+18]==126)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c126=wt126 if (crisis[_n+19]==1&ifscode[_n+19]==126)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c126=wt126 if (crisis[_n+20]==1&ifscode[_n+20]==126)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c126=wt126 if (crisis[_n+21]==1&ifscode[_n+21]==126)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c156=0

replace c156=wt156 if (crisis[_n-1]==1&ifscode[_n-1]==156)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c156=wt156 if (crisis[_n-2]==1&ifscode[_n-2]==156)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c156=wt156 if (crisis[_n-3]==1&ifscode[_n-3]==156)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c156=wt156 if (crisis[_n-4]==1&ifscode[_n-4]==156)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c156=wt156 if (crisis[_n-5]==1&ifscode[_n-5]==156)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c156=wt156 if (crisis[_n-6]==1&ifscode[_n-6]==156)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c156=wt156 if (crisis[_n-7]==1&ifscode[_n-7]==156)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c156=wt156 if (crisis[_n-8]==1&ifscode[_n-8]==156)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c156=wt156 if (crisis[_n-9]==1&ifscode[_n-9]==156)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c156=wt156 if (crisis[_n-10]==1&ifscode[_n-10]==156)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c156=wt156 if (crisis[_n-11]==1&ifscode[_n-11]==156)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c156=wt156 if (crisis[_n-12]==1&ifscode[_n-12]==156)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c156=wt156 if (crisis[_n-13]==1&ifscode[_n-13]==156)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c156=wt156 if (crisis[_n-14]==1&ifscode[_n-14]==156)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c156=wt156 if (crisis[_n-15]==1&ifscode[_n-15]==156)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c156=wt156 if (crisis[_n-16]==1&ifscode[_n-16]==156)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c156=wt156 if (crisis[_n-17]==1&ifscode[_n-17]==156)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c156=wt156 if (crisis[_n-18]==1&ifscode[_n-18]==156)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c156=wt156 if (crisis[_n-19]==1&ifscode[_n-19]==156)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c156=wt156 if (crisis[_n-20]==1&ifscode[_n-20]==156)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c156=wt156 if (crisis[_n-21]==1&ifscode[_n-21]==156)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c156=wt156 if (crisis[_n+1]==1&ifscode[_n+1]==156)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c156=wt156 if (crisis[_n+2]==1&ifscode[_n+2]==156)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c156=wt156 if (crisis[_n+3]==1&ifscode[_n+3]==156)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c156=wt156 if (crisis[_n+4]==1&ifscode[_n+4]==156)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c156=wt156 if (crisis[_n+5]==1&ifscode[_n+5]==156)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c156=wt156 if (crisis[_n+6]==1&ifscode[_n+6]==156)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c156=wt156 if (crisis[_n+7]==1&ifscode[_n+7]==156)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c156=wt156 if (crisis[_n+8]==1&ifscode[_n+8]==156)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c156=wt156 if (crisis[_n+9]==1&ifscode[_n+9]==156)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c156=wt156 if (crisis[_n+10]==1&ifscode[_n+10]==156)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c156=wt156 if (crisis[_n+11]==1&ifscode[_n+11]==156)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c156=wt156 if (crisis[_n+12]==1&ifscode[_n+12]==156)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c156=wt156 if (crisis[_n+13]==1&ifscode[_n+13]==156)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c156=wt156 if (crisis[_n+14]==1&ifscode[_n+14]==156)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c156=wt156 if (crisis[_n+15]==1&ifscode[_n+15]==156)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c156=wt156 if (crisis[_n+16]==1&ifscode[_n+16]==156)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c156=wt156 if (crisis[_n+17]==1&ifscode[_n+17]==156)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c156=wt156 if (crisis[_n+18]==1&ifscode[_n+18]==156)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c156=wt156 if (crisis[_n+19]==1&ifscode[_n+19]==156)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c156=wt156 if (crisis[_n+20]==1&ifscode[_n+20]==156)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c156=wt156 if (crisis[_n+21]==1&ifscode[_n+21]==156)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c128=0

replace c128=wt128 if (crisis[_n-1]==1&ifscode[_n-1]==128)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c128=wt128 if (crisis[_n-2]==1&ifscode[_n-2]==128)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c128=wt128 if (crisis[_n-3]==1&ifscode[_n-3]==128)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c128=wt128 if (crisis[_n-4]==1&ifscode[_n-4]==128)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c128=wt128 if (crisis[_n-5]==1&ifscode[_n-5]==128)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c128=wt128 if (crisis[_n-6]==1&ifscode[_n-6]==128)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c128=wt128 if (crisis[_n-7]==1&ifscode[_n-7]==128)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c128=wt128 if (crisis[_n-8]==1&ifscode[_n-8]==128)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c128=wt128 if (crisis[_n-9]==1&ifscode[_n-9]==128)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c128=wt128 if (crisis[_n-10]==1&ifscode[_n-10]==128)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c128=wt128 if (crisis[_n-11]==1&ifscode[_n-11]==128)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c128=wt128 if (crisis[_n-12]==1&ifscode[_n-12]==128)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c128=wt128 if (crisis[_n-13]==1&ifscode[_n-13]==128)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c128=wt128 if (crisis[_n-14]==1&ifscode[_n-14]==128)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c128=wt128 if (crisis[_n-15]==1&ifscode[_n-15]==128)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c128=wt128 if (crisis[_n-16]==1&ifscode[_n-16]==128)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c128=wt128 if (crisis[_n-17]==1&ifscode[_n-17]==128)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c128=wt128 if (crisis[_n-18]==1&ifscode[_n-18]==128)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c128=wt128 if (crisis[_n-19]==1&ifscode[_n-19]==128)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c128=wt128 if (crisis[_n-20]==1&ifscode[_n-20]==128)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c128=wt128 if (crisis[_n-21]==1&ifscode[_n-21]==128)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c128=wt128 if (crisis[_n+1]==1&ifscode[_n+1]==128)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c128=wt128 if (crisis[_n+2]==1&ifscode[_n+2]==128)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c128=wt128 if (crisis[_n+3]==1&ifscode[_n+3]==128)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c128=wt128 if (crisis[_n+4]==1&ifscode[_n+4]==128)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c128=wt128 if (crisis[_n+5]==1&ifscode[_n+5]==128)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c128=wt128 if (crisis[_n+6]==1&ifscode[_n+6]==128)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c128=wt128 if (crisis[_n+7]==1&ifscode[_n+7]==128)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c128=wt128 if (crisis[_n+8]==1&ifscode[_n+8]==128)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c128=wt128 if (crisis[_n+9]==1&ifscode[_n+9]==128)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c128=wt128 if (crisis[_n+10]==1&ifscode[_n+10]==128)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c128=wt128 if (crisis[_n+11]==1&ifscode[_n+11]==128)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c128=wt128 if (crisis[_n+12]==1&ifscode[_n+12]==128)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c128=wt128 if (crisis[_n+13]==1&ifscode[_n+13]==128)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c128=wt128 if (crisis[_n+14]==1&ifscode[_n+14]==128)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c128=wt128 if (crisis[_n+15]==1&ifscode[_n+15]==128)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c128=wt128 if (crisis[_n+16]==1&ifscode[_n+16]==128)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c128=wt128 if (crisis[_n+17]==1&ifscode[_n+17]==128)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c128=wt128 if (crisis[_n+18]==1&ifscode[_n+18]==128)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c128=wt128 if (crisis[_n+19]==1&ifscode[_n+19]==128)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c128=wt128 if (crisis[_n+20]==1&ifscode[_n+20]==128)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c128=wt128 if (crisis[_n+21]==1&ifscode[_n+21]==128)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c172=0

replace c172=wt172 if (crisis[_n-1]==1&ifscode[_n-1]==172)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c172=wt172 if (crisis[_n-2]==1&ifscode[_n-2]==172)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c172=wt172 if (crisis[_n-3]==1&ifscode[_n-3]==172)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c172=wt172 if (crisis[_n-4]==1&ifscode[_n-4]==172)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c172=wt172 if (crisis[_n-5]==1&ifscode[_n-5]==172)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c172=wt172 if (crisis[_n-6]==1&ifscode[_n-6]==172)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c172=wt172 if (crisis[_n-7]==1&ifscode[_n-7]==172)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c172=wt172 if (crisis[_n-8]==1&ifscode[_n-8]==172)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c172=wt172 if (crisis[_n-9]==1&ifscode[_n-9]==172)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c172=wt172 if (crisis[_n-10]==1&ifscode[_n-10]==172)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c172=wt172 if (crisis[_n-11]==1&ifscode[_n-11]==172)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c172=wt172 if (crisis[_n-12]==1&ifscode[_n-12]==172)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c172=wt172 if (crisis[_n-13]==1&ifscode[_n-13]==172)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c172=wt172 if (crisis[_n-14]==1&ifscode[_n-14]==172)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c172=wt172 if (crisis[_n-15]==1&ifscode[_n-15]==172)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c172=wt172 if (crisis[_n-16]==1&ifscode[_n-16]==172)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c172=wt172 if (crisis[_n-17]==1&ifscode[_n-17]==172)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c172=wt172 if (crisis[_n-18]==1&ifscode[_n-18]==172)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c172=wt172 if (crisis[_n-19]==1&ifscode[_n-19]==172)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c172=wt172 if (crisis[_n-20]==1&ifscode[_n-20]==172)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c172=wt172 if (crisis[_n-21]==1&ifscode[_n-21]==172)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c172=wt172 if (crisis[_n+1]==1&ifscode[_n+1]==172)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c172=wt172 if (crisis[_n+2]==1&ifscode[_n+2]==172)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c172=wt172 if (crisis[_n+3]==1&ifscode[_n+3]==172)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c172=wt172 if (crisis[_n+4]==1&ifscode[_n+4]==172)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c172=wt172 if (crisis[_n+5]==1&ifscode[_n+5]==172)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c172=wt172 if (crisis[_n+6]==1&ifscode[_n+6]==172)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c172=wt172 if (crisis[_n+7]==1&ifscode[_n+7]==172)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c172=wt172 if (crisis[_n+8]==1&ifscode[_n+8]==172)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c172=wt172 if (crisis[_n+9]==1&ifscode[_n+9]==172)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c172=wt172 if (crisis[_n+10]==1&ifscode[_n+10]==172)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c172=wt172 if (crisis[_n+11]==1&ifscode[_n+11]==172)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c172=wt172 if (crisis[_n+12]==1&ifscode[_n+12]==172)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c172=wt172 if (crisis[_n+13]==1&ifscode[_n+13]==172)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c172=wt172 if (crisis[_n+14]==1&ifscode[_n+14]==172)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c172=wt172 if (crisis[_n+15]==1&ifscode[_n+15]==172)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c172=wt172 if (crisis[_n+16]==1&ifscode[_n+16]==172)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c172=wt172 if (crisis[_n+17]==1&ifscode[_n+17]==172)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c172=wt172 if (crisis[_n+18]==1&ifscode[_n+18]==172)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c172=wt172 if (crisis[_n+19]==1&ifscode[_n+19]==172)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c172=wt172 if (crisis[_n+20]==1&ifscode[_n+20]==172)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c172=wt172 if (crisis[_n+21]==1&ifscode[_n+21]==172)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c132=0

replace c132=wt132 if (crisis[_n-1]==1&ifscode[_n-1]==132)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c132=wt132 if (crisis[_n-2]==1&ifscode[_n-2]==132)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c132=wt132 if (crisis[_n-3]==1&ifscode[_n-3]==132)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c132=wt132 if (crisis[_n-4]==1&ifscode[_n-4]==132)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c132=wt132 if (crisis[_n-5]==1&ifscode[_n-5]==132)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c132=wt132 if (crisis[_n-6]==1&ifscode[_n-6]==132)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c132=wt132 if (crisis[_n-7]==1&ifscode[_n-7]==132)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c132=wt132 if (crisis[_n-8]==1&ifscode[_n-8]==132)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c132=wt132 if (crisis[_n-9]==1&ifscode[_n-9]==132)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c132=wt132 if (crisis[_n-10]==1&ifscode[_n-10]==132)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c132=wt132 if (crisis[_n-11]==1&ifscode[_n-11]==132)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c132=wt132 if (crisis[_n-12]==1&ifscode[_n-12]==132)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c132=wt132 if (crisis[_n-13]==1&ifscode[_n-13]==132)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c132=wt132 if (crisis[_n-14]==1&ifscode[_n-14]==132)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c132=wt132 if (crisis[_n-15]==1&ifscode[_n-15]==132)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c132=wt132 if (crisis[_n-16]==1&ifscode[_n-16]==132)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c132=wt132 if (crisis[_n-17]==1&ifscode[_n-17]==132)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c132=wt132 if (crisis[_n-18]==1&ifscode[_n-18]==132)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c132=wt132 if (crisis[_n-19]==1&ifscode[_n-19]==132)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c132=wt132 if (crisis[_n-20]==1&ifscode[_n-20]==132)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c132=wt132 if (crisis[_n-21]==1&ifscode[_n-21]==132)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c132=wt132 if (crisis[_n+1]==1&ifscode[_n+1]==132)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c132=wt132 if (crisis[_n+2]==1&ifscode[_n+2]==132)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c132=wt132 if (crisis[_n+3]==1&ifscode[_n+3]==132)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c132=wt132 if (crisis[_n+4]==1&ifscode[_n+4]==132)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c132=wt132 if (crisis[_n+5]==1&ifscode[_n+5]==132)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c132=wt132 if (crisis[_n+6]==1&ifscode[_n+6]==132)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c132=wt132 if (crisis[_n+7]==1&ifscode[_n+7]==132)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c132=wt132 if (crisis[_n+8]==1&ifscode[_n+8]==132)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c132=wt132 if (crisis[_n+9]==1&ifscode[_n+9]==132)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c132=wt132 if (crisis[_n+10]==1&ifscode[_n+10]==132)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c132=wt132 if (crisis[_n+11]==1&ifscode[_n+11]==132)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c132=wt132 if (crisis[_n+12]==1&ifscode[_n+12]==132)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c132=wt132 if (crisis[_n+13]==1&ifscode[_n+13]==132)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c132=wt132 if (crisis[_n+14]==1&ifscode[_n+14]==132)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c132=wt132 if (crisis[_n+15]==1&ifscode[_n+15]==132)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c132=wt132 if (crisis[_n+16]==1&ifscode[_n+16]==132)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c132=wt132 if (crisis[_n+17]==1&ifscode[_n+17]==132)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c132=wt132 if (crisis[_n+18]==1&ifscode[_n+18]==132)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c132=wt132 if (crisis[_n+19]==1&ifscode[_n+19]==132)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c132=wt132 if (crisis[_n+20]==1&ifscode[_n+20]==132)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c132=wt132 if (crisis[_n+21]==1&ifscode[_n+21]==132)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c134=0

replace c134=wt134 if (crisis[_n-1]==1&ifscode[_n-1]==134)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c134=wt134 if (crisis[_n-2]==1&ifscode[_n-2]==134)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c134=wt134 if (crisis[_n-3]==1&ifscode[_n-3]==134)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c134=wt134 if (crisis[_n-4]==1&ifscode[_n-4]==134)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c134=wt134 if (crisis[_n-5]==1&ifscode[_n-5]==134)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c134=wt134 if (crisis[_n-6]==1&ifscode[_n-6]==134)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c134=wt134 if (crisis[_n-7]==1&ifscode[_n-7]==134)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c134=wt134 if (crisis[_n-8]==1&ifscode[_n-8]==134)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c134=wt134 if (crisis[_n-9]==1&ifscode[_n-9]==134)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c134=wt134 if (crisis[_n-10]==1&ifscode[_n-10]==134)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c134=wt134 if (crisis[_n-11]==1&ifscode[_n-11]==134)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c134=wt134 if (crisis[_n-12]==1&ifscode[_n-12]==134)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c134=wt134 if (crisis[_n-13]==1&ifscode[_n-13]==134)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c134=wt134 if (crisis[_n-14]==1&ifscode[_n-14]==134)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c134=wt134 if (crisis[_n-15]==1&ifscode[_n-15]==134)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c134=wt134 if (crisis[_n-16]==1&ifscode[_n-16]==134)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c134=wt134 if (crisis[_n-17]==1&ifscode[_n-17]==134)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c134=wt134 if (crisis[_n-18]==1&ifscode[_n-18]==134)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c134=wt134 if (crisis[_n-19]==1&ifscode[_n-19]==134)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c134=wt134 if (crisis[_n-20]==1&ifscode[_n-20]==134)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c134=wt134 if (crisis[_n-21]==1&ifscode[_n-21]==134)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c134=wt134 if (crisis[_n+1]==1&ifscode[_n+1]==134)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c134=wt134 if (crisis[_n+2]==1&ifscode[_n+2]==134)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c134=wt134 if (crisis[_n+3]==1&ifscode[_n+3]==134)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c134=wt134 if (crisis[_n+4]==1&ifscode[_n+4]==134)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c134=wt134 if (crisis[_n+5]==1&ifscode[_n+5]==134)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c134=wt134 if (crisis[_n+6]==1&ifscode[_n+6]==134)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c134=wt134 if (crisis[_n+7]==1&ifscode[_n+7]==134)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c134=wt134 if (crisis[_n+8]==1&ifscode[_n+8]==134)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c134=wt134 if (crisis[_n+9]==1&ifscode[_n+9]==134)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c134=wt134 if (crisis[_n+10]==1&ifscode[_n+10]==134)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c134=wt134 if (crisis[_n+11]==1&ifscode[_n+11]==134)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c134=wt134 if (crisis[_n+12]==1&ifscode[_n+12]==134)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c134=wt134 if (crisis[_n+13]==1&ifscode[_n+13]==134)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c134=wt134 if (crisis[_n+14]==1&ifscode[_n+14]==134)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c134=wt134 if (crisis[_n+15]==1&ifscode[_n+15]==134)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c134=wt134 if (crisis[_n+16]==1&ifscode[_n+16]==134)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c134=wt134 if (crisis[_n+17]==1&ifscode[_n+17]==134)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c134=wt134 if (crisis[_n+18]==1&ifscode[_n+18]==134)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c134=wt134 if (crisis[_n+19]==1&ifscode[_n+19]==134)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c134=wt134 if (crisis[_n+20]==1&ifscode[_n+20]==134)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c134=wt134 if (crisis[_n+21]==1&ifscode[_n+21]==134)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c174=0

replace c174=wt174 if (crisis[_n-1]==1&ifscode[_n-1]==174)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c174=wt174 if (crisis[_n-2]==1&ifscode[_n-2]==174)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c174=wt174 if (crisis[_n-3]==1&ifscode[_n-3]==174)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c174=wt174 if (crisis[_n-4]==1&ifscode[_n-4]==174)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c174=wt174 if (crisis[_n-5]==1&ifscode[_n-5]==174)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c174=wt174 if (crisis[_n-6]==1&ifscode[_n-6]==174)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c174=wt174 if (crisis[_n-7]==1&ifscode[_n-7]==174)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c174=wt174 if (crisis[_n-8]==1&ifscode[_n-8]==174)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c174=wt174 if (crisis[_n-9]==1&ifscode[_n-9]==174)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c174=wt174 if (crisis[_n-10]==1&ifscode[_n-10]==174)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c174=wt174 if (crisis[_n-11]==1&ifscode[_n-11]==174)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c174=wt174 if (crisis[_n-12]==1&ifscode[_n-12]==174)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c174=wt174 if (crisis[_n-13]==1&ifscode[_n-13]==174)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c174=wt174 if (crisis[_n-14]==1&ifscode[_n-14]==174)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c174=wt174 if (crisis[_n-15]==1&ifscode[_n-15]==174)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c174=wt174 if (crisis[_n-16]==1&ifscode[_n-16]==174)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c174=wt174 if (crisis[_n-17]==1&ifscode[_n-17]==174)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c174=wt174 if (crisis[_n-18]==1&ifscode[_n-18]==174)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c174=wt174 if (crisis[_n-19]==1&ifscode[_n-19]==174)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c174=wt174 if (crisis[_n-20]==1&ifscode[_n-20]==174)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c174=wt174 if (crisis[_n-21]==1&ifscode[_n-21]==174)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c174=wt174 if (crisis[_n+1]==1&ifscode[_n+1]==174)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c174=wt174 if (crisis[_n+2]==1&ifscode[_n+2]==174)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c174=wt174 if (crisis[_n+3]==1&ifscode[_n+3]==174)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c174=wt174 if (crisis[_n+4]==1&ifscode[_n+4]==174)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c174=wt174 if (crisis[_n+5]==1&ifscode[_n+5]==174)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c174=wt174 if (crisis[_n+6]==1&ifscode[_n+6]==174)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c174=wt174 if (crisis[_n+7]==1&ifscode[_n+7]==174)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c174=wt174 if (crisis[_n+8]==1&ifscode[_n+8]==174)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c174=wt174 if (crisis[_n+9]==1&ifscode[_n+9]==174)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c174=wt174 if (crisis[_n+10]==1&ifscode[_n+10]==174)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c174=wt174 if (crisis[_n+11]==1&ifscode[_n+11]==174)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c174=wt174 if (crisis[_n+12]==1&ifscode[_n+12]==174)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c174=wt174 if (crisis[_n+13]==1&ifscode[_n+13]==174)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c174=wt174 if (crisis[_n+14]==1&ifscode[_n+14]==174)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c174=wt174 if (crisis[_n+15]==1&ifscode[_n+15]==174)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c174=wt174 if (crisis[_n+16]==1&ifscode[_n+16]==174)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c174=wt174 if (crisis[_n+17]==1&ifscode[_n+17]==174)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c174=wt174 if (crisis[_n+18]==1&ifscode[_n+18]==174)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c174=wt174 if (crisis[_n+19]==1&ifscode[_n+19]==174)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c174=wt174 if (crisis[_n+20]==1&ifscode[_n+20]==174)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c174=wt174 if (crisis[_n+21]==1&ifscode[_n+21]==174)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c178=0

replace c178=wt178 if (crisis[_n-1]==1&ifscode[_n-1]==178)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c178=wt178 if (crisis[_n-2]==1&ifscode[_n-2]==178)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c178=wt178 if (crisis[_n-3]==1&ifscode[_n-3]==178)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c178=wt178 if (crisis[_n-4]==1&ifscode[_n-4]==178)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c178=wt178 if (crisis[_n-5]==1&ifscode[_n-5]==178)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c178=wt178 if (crisis[_n-6]==1&ifscode[_n-6]==178)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c178=wt178 if (crisis[_n-7]==1&ifscode[_n-7]==178)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c178=wt178 if (crisis[_n-8]==1&ifscode[_n-8]==178)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c178=wt178 if (crisis[_n-9]==1&ifscode[_n-9]==178)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c178=wt178 if (crisis[_n-10]==1&ifscode[_n-10]==178)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c178=wt178 if (crisis[_n-11]==1&ifscode[_n-11]==178)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c178=wt178 if (crisis[_n-12]==1&ifscode[_n-12]==178)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c178=wt178 if (crisis[_n-13]==1&ifscode[_n-13]==178)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c178=wt178 if (crisis[_n-14]==1&ifscode[_n-14]==178)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c178=wt178 if (crisis[_n-15]==1&ifscode[_n-15]==178)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c178=wt178 if (crisis[_n-16]==1&ifscode[_n-16]==178)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c178=wt178 if (crisis[_n-17]==1&ifscode[_n-17]==178)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c178=wt178 if (crisis[_n-18]==1&ifscode[_n-18]==178)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c178=wt178 if (crisis[_n-19]==1&ifscode[_n-19]==178)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c178=wt178 if (crisis[_n-20]==1&ifscode[_n-20]==178)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c178=wt178 if (crisis[_n-21]==1&ifscode[_n-21]==178)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c178=wt178 if (crisis[_n+1]==1&ifscode[_n+1]==178)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c178=wt178 if (crisis[_n+2]==1&ifscode[_n+2]==178)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c178=wt178 if (crisis[_n+3]==1&ifscode[_n+3]==178)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c178=wt178 if (crisis[_n+4]==1&ifscode[_n+4]==178)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c178=wt178 if (crisis[_n+5]==1&ifscode[_n+5]==178)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c178=wt178 if (crisis[_n+6]==1&ifscode[_n+6]==178)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c178=wt178 if (crisis[_n+7]==1&ifscode[_n+7]==178)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c178=wt178 if (crisis[_n+8]==1&ifscode[_n+8]==178)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c178=wt178 if (crisis[_n+9]==1&ifscode[_n+9]==178)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c178=wt178 if (crisis[_n+10]==1&ifscode[_n+10]==178)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c178=wt178 if (crisis[_n+11]==1&ifscode[_n+11]==178)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c178=wt178 if (crisis[_n+12]==1&ifscode[_n+12]==178)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c178=wt178 if (crisis[_n+13]==1&ifscode[_n+13]==178)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c178=wt178 if (crisis[_n+14]==1&ifscode[_n+14]==178)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c178=wt178 if (crisis[_n+15]==1&ifscode[_n+15]==178)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c178=wt178 if (crisis[_n+16]==1&ifscode[_n+16]==178)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c178=wt178 if (crisis[_n+17]==1&ifscode[_n+17]==178)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c178=wt178 if (crisis[_n+18]==1&ifscode[_n+18]==178)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c178=wt178 if (crisis[_n+19]==1&ifscode[_n+19]==178)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c178=wt178 if (crisis[_n+20]==1&ifscode[_n+20]==178)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c178=wt178 if (crisis[_n+21]==1&ifscode[_n+21]==178)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c136=0

replace c136=wt136 if (crisis[_n-1]==1&ifscode[_n-1]==136)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c136=wt136 if (crisis[_n-2]==1&ifscode[_n-2]==136)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c136=wt136 if (crisis[_n-3]==1&ifscode[_n-3]==136)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c136=wt136 if (crisis[_n-4]==1&ifscode[_n-4]==136)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c136=wt136 if (crisis[_n-5]==1&ifscode[_n-5]==136)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c136=wt136 if (crisis[_n-6]==1&ifscode[_n-6]==136)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c136=wt136 if (crisis[_n-7]==1&ifscode[_n-7]==136)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c136=wt136 if (crisis[_n-8]==1&ifscode[_n-8]==136)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c136=wt136 if (crisis[_n-9]==1&ifscode[_n-9]==136)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c136=wt136 if (crisis[_n-10]==1&ifscode[_n-10]==136)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c136=wt136 if (crisis[_n-11]==1&ifscode[_n-11]==136)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c136=wt136 if (crisis[_n-12]==1&ifscode[_n-12]==136)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c136=wt136 if (crisis[_n-13]==1&ifscode[_n-13]==136)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c136=wt136 if (crisis[_n-14]==1&ifscode[_n-14]==136)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c136=wt136 if (crisis[_n-15]==1&ifscode[_n-15]==136)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c136=wt136 if (crisis[_n-16]==1&ifscode[_n-16]==136)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c136=wt136 if (crisis[_n-17]==1&ifscode[_n-17]==136)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c136=wt136 if (crisis[_n-18]==1&ifscode[_n-18]==136)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c136=wt136 if (crisis[_n-19]==1&ifscode[_n-19]==136)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c136=wt136 if (crisis[_n-20]==1&ifscode[_n-20]==136)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c136=wt136 if (crisis[_n-21]==1&ifscode[_n-21]==136)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c136=wt136 if (crisis[_n+1]==1&ifscode[_n+1]==136)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c136=wt136 if (crisis[_n+2]==1&ifscode[_n+2]==136)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c136=wt136 if (crisis[_n+3]==1&ifscode[_n+3]==136)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c136=wt136 if (crisis[_n+4]==1&ifscode[_n+4]==136)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c136=wt136 if (crisis[_n+5]==1&ifscode[_n+5]==136)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c136=wt136 if (crisis[_n+6]==1&ifscode[_n+6]==136)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c136=wt136 if (crisis[_n+7]==1&ifscode[_n+7]==136)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c136=wt136 if (crisis[_n+8]==1&ifscode[_n+8]==136)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c136=wt136 if (crisis[_n+9]==1&ifscode[_n+9]==136)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c136=wt136 if (crisis[_n+10]==1&ifscode[_n+10]==136)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c136=wt136 if (crisis[_n+11]==1&ifscode[_n+11]==136)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c136=wt136 if (crisis[_n+12]==1&ifscode[_n+12]==136)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c136=wt136 if (crisis[_n+13]==1&ifscode[_n+13]==136)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c136=wt136 if (crisis[_n+14]==1&ifscode[_n+14]==136)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c136=wt136 if (crisis[_n+15]==1&ifscode[_n+15]==136)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c136=wt136 if (crisis[_n+16]==1&ifscode[_n+16]==136)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c136=wt136 if (crisis[_n+17]==1&ifscode[_n+17]==136)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c136=wt136 if (crisis[_n+18]==1&ifscode[_n+18]==136)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c136=wt136 if (crisis[_n+19]==1&ifscode[_n+19]==136)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c136=wt136 if (crisis[_n+20]==1&ifscode[_n+20]==136)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c136=wt136 if (crisis[_n+21]==1&ifscode[_n+21]==136)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c158=0

replace c158=wt158 if (crisis[_n-1]==1&ifscode[_n-1]==158)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c158=wt158 if (crisis[_n-2]==1&ifscode[_n-2]==158)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c158=wt158 if (crisis[_n-3]==1&ifscode[_n-3]==158)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c158=wt158 if (crisis[_n-4]==1&ifscode[_n-4]==158)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c158=wt158 if (crisis[_n-5]==1&ifscode[_n-5]==158)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c158=wt158 if (crisis[_n-6]==1&ifscode[_n-6]==158)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c158=wt158 if (crisis[_n-7]==1&ifscode[_n-7]==158)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c158=wt158 if (crisis[_n-8]==1&ifscode[_n-8]==158)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c158=wt158 if (crisis[_n-9]==1&ifscode[_n-9]==158)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c158=wt158 if (crisis[_n-10]==1&ifscode[_n-10]==158)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c158=wt158 if (crisis[_n-11]==1&ifscode[_n-11]==158)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c158=wt158 if (crisis[_n-12]==1&ifscode[_n-12]==158)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c158=wt158 if (crisis[_n-13]==1&ifscode[_n-13]==158)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c158=wt158 if (crisis[_n-14]==1&ifscode[_n-14]==158)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c158=wt158 if (crisis[_n-15]==1&ifscode[_n-15]==158)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c158=wt158 if (crisis[_n-16]==1&ifscode[_n-16]==158)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c158=wt158 if (crisis[_n-17]==1&ifscode[_n-17]==158)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c158=wt158 if (crisis[_n-18]==1&ifscode[_n-18]==158)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c158=wt158 if (crisis[_n-19]==1&ifscode[_n-19]==158)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c158=wt158 if (crisis[_n-20]==1&ifscode[_n-20]==158)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c158=wt158 if (crisis[_n-21]==1&ifscode[_n-21]==158)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c158=wt158 if (crisis[_n+1]==1&ifscode[_n+1]==158)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c158=wt158 if (crisis[_n+2]==1&ifscode[_n+2]==158)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c158=wt158 if (crisis[_n+3]==1&ifscode[_n+3]==158)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c158=wt158 if (crisis[_n+4]==1&ifscode[_n+4]==158)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c158=wt158 if (crisis[_n+5]==1&ifscode[_n+5]==158)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c158=wt158 if (crisis[_n+6]==1&ifscode[_n+6]==158)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c158=wt158 if (crisis[_n+7]==1&ifscode[_n+7]==158)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c158=wt158 if (crisis[_n+8]==1&ifscode[_n+8]==158)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c158=wt158 if (crisis[_n+9]==1&ifscode[_n+9]==158)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c158=wt158 if (crisis[_n+10]==1&ifscode[_n+10]==158)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c158=wt158 if (crisis[_n+11]==1&ifscode[_n+11]==158)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c158=wt158 if (crisis[_n+12]==1&ifscode[_n+12]==158)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c158=wt158 if (crisis[_n+13]==1&ifscode[_n+13]==158)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c158=wt158 if (crisis[_n+14]==1&ifscode[_n+14]==158)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c158=wt158 if (crisis[_n+15]==1&ifscode[_n+15]==158)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c158=wt158 if (crisis[_n+16]==1&ifscode[_n+16]==158)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c158=wt158 if (crisis[_n+17]==1&ifscode[_n+17]==158)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c158=wt158 if (crisis[_n+18]==1&ifscode[_n+18]==158)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c158=wt158 if (crisis[_n+19]==1&ifscode[_n+19]==158)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c158=wt158 if (crisis[_n+20]==1&ifscode[_n+20]==158)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c158=wt158 if (crisis[_n+21]==1&ifscode[_n+21]==158)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c138=0

replace c138=wt138 if (crisis[_n-1]==1&ifscode[_n-1]==138)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c138=wt138 if (crisis[_n-2]==1&ifscode[_n-2]==138)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c138=wt138 if (crisis[_n-3]==1&ifscode[_n-3]==138)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c138=wt138 if (crisis[_n-4]==1&ifscode[_n-4]==138)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c138=wt138 if (crisis[_n-5]==1&ifscode[_n-5]==138)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c138=wt138 if (crisis[_n-6]==1&ifscode[_n-6]==138)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c138=wt138 if (crisis[_n-7]==1&ifscode[_n-7]==138)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c138=wt138 if (crisis[_n-8]==1&ifscode[_n-8]==138)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c138=wt138 if (crisis[_n-9]==1&ifscode[_n-9]==138)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c138=wt138 if (crisis[_n-10]==1&ifscode[_n-10]==138)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c138=wt138 if (crisis[_n-11]==1&ifscode[_n-11]==138)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c138=wt138 if (crisis[_n-12]==1&ifscode[_n-12]==138)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c138=wt138 if (crisis[_n-13]==1&ifscode[_n-13]==138)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c138=wt138 if (crisis[_n-14]==1&ifscode[_n-14]==138)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c138=wt138 if (crisis[_n-15]==1&ifscode[_n-15]==138)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c138=wt138 if (crisis[_n-16]==1&ifscode[_n-16]==138)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c138=wt138 if (crisis[_n-17]==1&ifscode[_n-17]==138)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c138=wt138 if (crisis[_n-18]==1&ifscode[_n-18]==138)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c138=wt138 if (crisis[_n-19]==1&ifscode[_n-19]==138)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c138=wt138 if (crisis[_n-20]==1&ifscode[_n-20]==138)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c138=wt138 if (crisis[_n-21]==1&ifscode[_n-21]==138)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c138=wt138 if (crisis[_n+1]==1&ifscode[_n+1]==138)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c138=wt138 if (crisis[_n+2]==1&ifscode[_n+2]==138)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c138=wt138 if (crisis[_n+3]==1&ifscode[_n+3]==138)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c138=wt138 if (crisis[_n+4]==1&ifscode[_n+4]==138)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c138=wt138 if (crisis[_n+5]==1&ifscode[_n+5]==138)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c138=wt138 if (crisis[_n+6]==1&ifscode[_n+6]==138)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c138=wt138 if (crisis[_n+7]==1&ifscode[_n+7]==138)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c138=wt138 if (crisis[_n+8]==1&ifscode[_n+8]==138)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c138=wt138 if (crisis[_n+9]==1&ifscode[_n+9]==138)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c138=wt138 if (crisis[_n+10]==1&ifscode[_n+10]==138)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c138=wt138 if (crisis[_n+11]==1&ifscode[_n+11]==138)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c138=wt138 if (crisis[_n+12]==1&ifscode[_n+12]==138)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c138=wt138 if (crisis[_n+13]==1&ifscode[_n+13]==138)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c138=wt138 if (crisis[_n+14]==1&ifscode[_n+14]==138)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c138=wt138 if (crisis[_n+15]==1&ifscode[_n+15]==138)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c138=wt138 if (crisis[_n+16]==1&ifscode[_n+16]==138)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c138=wt138 if (crisis[_n+17]==1&ifscode[_n+17]==138)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c138=wt138 if (crisis[_n+18]==1&ifscode[_n+18]==138)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c138=wt138 if (crisis[_n+19]==1&ifscode[_n+19]==138)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c138=wt138 if (crisis[_n+20]==1&ifscode[_n+20]==138)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c138=wt138 if (crisis[_n+21]==1&ifscode[_n+21]==138)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c196=0

replace c196=wt196 if (crisis[_n-1]==1&ifscode[_n-1]==196)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c196=wt196 if (crisis[_n-2]==1&ifscode[_n-2]==196)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c196=wt196 if (crisis[_n-3]==1&ifscode[_n-3]==196)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c196=wt196 if (crisis[_n-4]==1&ifscode[_n-4]==196)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c196=wt196 if (crisis[_n-5]==1&ifscode[_n-5]==196)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c196=wt196 if (crisis[_n-6]==1&ifscode[_n-6]==196)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c196=wt196 if (crisis[_n-7]==1&ifscode[_n-7]==196)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c196=wt196 if (crisis[_n-8]==1&ifscode[_n-8]==196)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c196=wt196 if (crisis[_n-9]==1&ifscode[_n-9]==196)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c196=wt196 if (crisis[_n-10]==1&ifscode[_n-10]==196)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c196=wt196 if (crisis[_n-11]==1&ifscode[_n-11]==196)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c196=wt196 if (crisis[_n-12]==1&ifscode[_n-12]==196)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c196=wt196 if (crisis[_n-13]==1&ifscode[_n-13]==196)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c196=wt196 if (crisis[_n-14]==1&ifscode[_n-14]==196)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c196=wt196 if (crisis[_n-15]==1&ifscode[_n-15]==196)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c196=wt196 if (crisis[_n-16]==1&ifscode[_n-16]==196)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c196=wt196 if (crisis[_n-17]==1&ifscode[_n-17]==196)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c196=wt196 if (crisis[_n-18]==1&ifscode[_n-18]==196)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c196=wt196 if (crisis[_n-19]==1&ifscode[_n-19]==196)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c196=wt196 if (crisis[_n-20]==1&ifscode[_n-20]==196)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c196=wt196 if (crisis[_n-21]==1&ifscode[_n-21]==196)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c196=wt196 if (crisis[_n+1]==1&ifscode[_n+1]==196)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c196=wt196 if (crisis[_n+2]==1&ifscode[_n+2]==196)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c196=wt196 if (crisis[_n+3]==1&ifscode[_n+3]==196)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c196=wt196 if (crisis[_n+4]==1&ifscode[_n+4]==196)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c196=wt196 if (crisis[_n+5]==1&ifscode[_n+5]==196)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c196=wt196 if (crisis[_n+6]==1&ifscode[_n+6]==196)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c196=wt196 if (crisis[_n+7]==1&ifscode[_n+7]==196)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c196=wt196 if (crisis[_n+8]==1&ifscode[_n+8]==196)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c196=wt196 if (crisis[_n+9]==1&ifscode[_n+9]==196)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c196=wt196 if (crisis[_n+10]==1&ifscode[_n+10]==196)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c196=wt196 if (crisis[_n+11]==1&ifscode[_n+11]==196)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c196=wt196 if (crisis[_n+12]==1&ifscode[_n+12]==196)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c196=wt196 if (crisis[_n+13]==1&ifscode[_n+13]==196)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c196=wt196 if (crisis[_n+14]==1&ifscode[_n+14]==196)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c196=wt196 if (crisis[_n+15]==1&ifscode[_n+15]==196)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c196=wt196 if (crisis[_n+16]==1&ifscode[_n+16]==196)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c196=wt196 if (crisis[_n+17]==1&ifscode[_n+17]==196)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c196=wt196 if (crisis[_n+18]==1&ifscode[_n+18]==196)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c196=wt196 if (crisis[_n+19]==1&ifscode[_n+19]==196)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c196=wt196 if (crisis[_n+20]==1&ifscode[_n+20]==196)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c196=wt196 if (crisis[_n+21]==1&ifscode[_n+21]==196)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c142=0

replace c142=wt142 if (crisis[_n-1]==1&ifscode[_n-1]==142)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c142=wt142 if (crisis[_n-2]==1&ifscode[_n-2]==142)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c142=wt142 if (crisis[_n-3]==1&ifscode[_n-3]==142)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c142=wt142 if (crisis[_n-4]==1&ifscode[_n-4]==142)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c142=wt142 if (crisis[_n-5]==1&ifscode[_n-5]==142)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c142=wt142 if (crisis[_n-6]==1&ifscode[_n-6]==142)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c142=wt142 if (crisis[_n-7]==1&ifscode[_n-7]==142)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c142=wt142 if (crisis[_n-8]==1&ifscode[_n-8]==142)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c142=wt142 if (crisis[_n-9]==1&ifscode[_n-9]==142)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c142=wt142 if (crisis[_n-10]==1&ifscode[_n-10]==142)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c142=wt142 if (crisis[_n-11]==1&ifscode[_n-11]==142)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c142=wt142 if (crisis[_n-12]==1&ifscode[_n-12]==142)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c142=wt142 if (crisis[_n-13]==1&ifscode[_n-13]==142)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c142=wt142 if (crisis[_n-14]==1&ifscode[_n-14]==142)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c142=wt142 if (crisis[_n-15]==1&ifscode[_n-15]==142)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c142=wt142 if (crisis[_n-16]==1&ifscode[_n-16]==142)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c142=wt142 if (crisis[_n-17]==1&ifscode[_n-17]==142)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c142=wt142 if (crisis[_n-18]==1&ifscode[_n-18]==142)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c142=wt142 if (crisis[_n-19]==1&ifscode[_n-19]==142)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c142=wt142 if (crisis[_n-20]==1&ifscode[_n-20]==142)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c142=wt142 if (crisis[_n-21]==1&ifscode[_n-21]==142)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c142=wt142 if (crisis[_n+1]==1&ifscode[_n+1]==142)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c142=wt142 if (crisis[_n+2]==1&ifscode[_n+2]==142)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c142=wt142 if (crisis[_n+3]==1&ifscode[_n+3]==142)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c142=wt142 if (crisis[_n+4]==1&ifscode[_n+4]==142)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c142=wt142 if (crisis[_n+5]==1&ifscode[_n+5]==142)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c142=wt142 if (crisis[_n+6]==1&ifscode[_n+6]==142)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c142=wt142 if (crisis[_n+7]==1&ifscode[_n+7]==142)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c142=wt142 if (crisis[_n+8]==1&ifscode[_n+8]==142)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c142=wt142 if (crisis[_n+9]==1&ifscode[_n+9]==142)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c142=wt142 if (crisis[_n+10]==1&ifscode[_n+10]==142)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c142=wt142 if (crisis[_n+11]==1&ifscode[_n+11]==142)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c142=wt142 if (crisis[_n+12]==1&ifscode[_n+12]==142)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c142=wt142 if (crisis[_n+13]==1&ifscode[_n+13]==142)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c142=wt142 if (crisis[_n+14]==1&ifscode[_n+14]==142)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c142=wt142 if (crisis[_n+15]==1&ifscode[_n+15]==142)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c142=wt142 if (crisis[_n+16]==1&ifscode[_n+16]==142)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c142=wt142 if (crisis[_n+17]==1&ifscode[_n+17]==142)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c142=wt142 if (crisis[_n+18]==1&ifscode[_n+18]==142)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c142=wt142 if (crisis[_n+19]==1&ifscode[_n+19]==142)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c142=wt142 if (crisis[_n+20]==1&ifscode[_n+20]==142)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c142=wt142 if (crisis[_n+21]==1&ifscode[_n+21]==142)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c182=0

replace c182=wt182 if (crisis[_n-1]==1&ifscode[_n-1]==182)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c182=wt182 if (crisis[_n-2]==1&ifscode[_n-2]==182)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c182=wt182 if (crisis[_n-3]==1&ifscode[_n-3]==182)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c182=wt182 if (crisis[_n-4]==1&ifscode[_n-4]==182)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c182=wt182 if (crisis[_n-5]==1&ifscode[_n-5]==182)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c182=wt182 if (crisis[_n-6]==1&ifscode[_n-6]==182)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c182=wt182 if (crisis[_n-7]==1&ifscode[_n-7]==182)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c182=wt182 if (crisis[_n-8]==1&ifscode[_n-8]==182)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c182=wt182 if (crisis[_n-9]==1&ifscode[_n-9]==182)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c182=wt182 if (crisis[_n-10]==1&ifscode[_n-10]==182)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c182=wt182 if (crisis[_n-11]==1&ifscode[_n-11]==182)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c182=wt182 if (crisis[_n-12]==1&ifscode[_n-12]==182)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c182=wt182 if (crisis[_n-13]==1&ifscode[_n-13]==182)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c182=wt182 if (crisis[_n-14]==1&ifscode[_n-14]==182)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c182=wt182 if (crisis[_n-15]==1&ifscode[_n-15]==182)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c182=wt182 if (crisis[_n-16]==1&ifscode[_n-16]==182)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c182=wt182 if (crisis[_n-17]==1&ifscode[_n-17]==182)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c182=wt182 if (crisis[_n-18]==1&ifscode[_n-18]==182)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c182=wt182 if (crisis[_n-19]==1&ifscode[_n-19]==182)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c182=wt182 if (crisis[_n-20]==1&ifscode[_n-20]==182)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c182=wt182 if (crisis[_n-21]==1&ifscode[_n-21]==182)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c182=wt182 if (crisis[_n+1]==1&ifscode[_n+1]==182)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c182=wt182 if (crisis[_n+2]==1&ifscode[_n+2]==182)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c182=wt182 if (crisis[_n+3]==1&ifscode[_n+3]==182)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c182=wt182 if (crisis[_n+4]==1&ifscode[_n+4]==182)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c182=wt182 if (crisis[_n+5]==1&ifscode[_n+5]==182)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c182=wt182 if (crisis[_n+6]==1&ifscode[_n+6]==182)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c182=wt182 if (crisis[_n+7]==1&ifscode[_n+7]==182)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c182=wt182 if (crisis[_n+8]==1&ifscode[_n+8]==182)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c182=wt182 if (crisis[_n+9]==1&ifscode[_n+9]==182)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c182=wt182 if (crisis[_n+10]==1&ifscode[_n+10]==182)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c182=wt182 if (crisis[_n+11]==1&ifscode[_n+11]==182)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c182=wt182 if (crisis[_n+12]==1&ifscode[_n+12]==182)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c182=wt182 if (crisis[_n+13]==1&ifscode[_n+13]==182)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c182=wt182 if (crisis[_n+14]==1&ifscode[_n+14]==182)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c182=wt182 if (crisis[_n+15]==1&ifscode[_n+15]==182)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c182=wt182 if (crisis[_n+16]==1&ifscode[_n+16]==182)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c182=wt182 if (crisis[_n+17]==1&ifscode[_n+17]==182)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c182=wt182 if (crisis[_n+18]==1&ifscode[_n+18]==182)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c182=wt182 if (crisis[_n+19]==1&ifscode[_n+19]==182)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c182=wt182 if (crisis[_n+20]==1&ifscode[_n+20]==182)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c182=wt182 if (crisis[_n+21]==1&ifscode[_n+21]==182)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c184=0

replace c184=wt184 if (crisis[_n-1]==1&ifscode[_n-1]==184)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c184=wt184 if (crisis[_n-2]==1&ifscode[_n-2]==184)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c184=wt184 if (crisis[_n-3]==1&ifscode[_n-3]==184)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c184=wt184 if (crisis[_n-4]==1&ifscode[_n-4]==184)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c184=wt184 if (crisis[_n-5]==1&ifscode[_n-5]==184)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c184=wt184 if (crisis[_n-6]==1&ifscode[_n-6]==184)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c184=wt184 if (crisis[_n-7]==1&ifscode[_n-7]==184)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c184=wt184 if (crisis[_n-8]==1&ifscode[_n-8]==184)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c184=wt184 if (crisis[_n-9]==1&ifscode[_n-9]==184)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c184=wt184 if (crisis[_n-10]==1&ifscode[_n-10]==184)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c184=wt184 if (crisis[_n-11]==1&ifscode[_n-11]==184)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c184=wt184 if (crisis[_n-12]==1&ifscode[_n-12]==184)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c184=wt184 if (crisis[_n-13]==1&ifscode[_n-13]==184)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c184=wt184 if (crisis[_n-14]==1&ifscode[_n-14]==184)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c184=wt184 if (crisis[_n-15]==1&ifscode[_n-15]==184)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c184=wt184 if (crisis[_n-16]==1&ifscode[_n-16]==184)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c184=wt184 if (crisis[_n-17]==1&ifscode[_n-17]==184)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c184=wt184 if (crisis[_n-18]==1&ifscode[_n-18]==184)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c184=wt184 if (crisis[_n-19]==1&ifscode[_n-19]==184)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c184=wt184 if (crisis[_n-20]==1&ifscode[_n-20]==184)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c184=wt184 if (crisis[_n-21]==1&ifscode[_n-21]==184)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c184=wt184 if (crisis[_n+1]==1&ifscode[_n+1]==184)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c184=wt184 if (crisis[_n+2]==1&ifscode[_n+2]==184)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c184=wt184 if (crisis[_n+3]==1&ifscode[_n+3]==184)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c184=wt184 if (crisis[_n+4]==1&ifscode[_n+4]==184)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c184=wt184 if (crisis[_n+5]==1&ifscode[_n+5]==184)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c184=wt184 if (crisis[_n+6]==1&ifscode[_n+6]==184)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c184=wt184 if (crisis[_n+7]==1&ifscode[_n+7]==184)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c184=wt184 if (crisis[_n+8]==1&ifscode[_n+8]==184)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c184=wt184 if (crisis[_n+9]==1&ifscode[_n+9]==184)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c184=wt184 if (crisis[_n+10]==1&ifscode[_n+10]==184)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c184=wt184 if (crisis[_n+11]==1&ifscode[_n+11]==184)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c184=wt184 if (crisis[_n+12]==1&ifscode[_n+12]==184)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c184=wt184 if (crisis[_n+13]==1&ifscode[_n+13]==184)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c184=wt184 if (crisis[_n+14]==1&ifscode[_n+14]==184)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c184=wt184 if (crisis[_n+15]==1&ifscode[_n+15]==184)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c184=wt184 if (crisis[_n+16]==1&ifscode[_n+16]==184)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c184=wt184 if (crisis[_n+17]==1&ifscode[_n+17]==184)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c184=wt184 if (crisis[_n+18]==1&ifscode[_n+18]==184)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c184=wt184 if (crisis[_n+19]==1&ifscode[_n+19]==184)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c184=wt184 if (crisis[_n+20]==1&ifscode[_n+20]==184)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c184=wt184 if (crisis[_n+21]==1&ifscode[_n+21]==184)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c144=0

replace c144=wt144 if (crisis[_n-1]==1&ifscode[_n-1]==144)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c144=wt144 if (crisis[_n-2]==1&ifscode[_n-2]==144)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c144=wt144 if (crisis[_n-3]==1&ifscode[_n-3]==144)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c144=wt144 if (crisis[_n-4]==1&ifscode[_n-4]==144)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c144=wt144 if (crisis[_n-5]==1&ifscode[_n-5]==144)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c144=wt144 if (crisis[_n-6]==1&ifscode[_n-6]==144)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c144=wt144 if (crisis[_n-7]==1&ifscode[_n-7]==144)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c144=wt144 if (crisis[_n-8]==1&ifscode[_n-8]==144)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c144=wt144 if (crisis[_n-9]==1&ifscode[_n-9]==144)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c144=wt144 if (crisis[_n-10]==1&ifscode[_n-10]==144)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c144=wt144 if (crisis[_n-11]==1&ifscode[_n-11]==144)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c144=wt144 if (crisis[_n-12]==1&ifscode[_n-12]==144)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c144=wt144 if (crisis[_n-13]==1&ifscode[_n-13]==144)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c144=wt144 if (crisis[_n-14]==1&ifscode[_n-14]==144)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c144=wt144 if (crisis[_n-15]==1&ifscode[_n-15]==144)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c144=wt144 if (crisis[_n-16]==1&ifscode[_n-16]==144)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c144=wt144 if (crisis[_n-17]==1&ifscode[_n-17]==144)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c144=wt144 if (crisis[_n-18]==1&ifscode[_n-18]==144)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c144=wt144 if (crisis[_n-19]==1&ifscode[_n-19]==144)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c144=wt144 if (crisis[_n-20]==1&ifscode[_n-20]==144)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c144=wt144 if (crisis[_n-21]==1&ifscode[_n-21]==144)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c144=wt144 if (crisis[_n+1]==1&ifscode[_n+1]==144)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c144=wt144 if (crisis[_n+2]==1&ifscode[_n+2]==144)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c144=wt144 if (crisis[_n+3]==1&ifscode[_n+3]==144)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c144=wt144 if (crisis[_n+4]==1&ifscode[_n+4]==144)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c144=wt144 if (crisis[_n+5]==1&ifscode[_n+5]==144)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c144=wt144 if (crisis[_n+6]==1&ifscode[_n+6]==144)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c144=wt144 if (crisis[_n+7]==1&ifscode[_n+7]==144)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c144=wt144 if (crisis[_n+8]==1&ifscode[_n+8]==144)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c144=wt144 if (crisis[_n+9]==1&ifscode[_n+9]==144)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c144=wt144 if (crisis[_n+10]==1&ifscode[_n+10]==144)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c144=wt144 if (crisis[_n+11]==1&ifscode[_n+11]==144)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c144=wt144 if (crisis[_n+12]==1&ifscode[_n+12]==144)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c144=wt144 if (crisis[_n+13]==1&ifscode[_n+13]==144)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c144=wt144 if (crisis[_n+14]==1&ifscode[_n+14]==144)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c144=wt144 if (crisis[_n+15]==1&ifscode[_n+15]==144)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c144=wt144 if (crisis[_n+16]==1&ifscode[_n+16]==144)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c144=wt144 if (crisis[_n+17]==1&ifscode[_n+17]==144)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c144=wt144 if (crisis[_n+18]==1&ifscode[_n+18]==144)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c144=wt144 if (crisis[_n+19]==1&ifscode[_n+19]==144)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c144=wt144 if (crisis[_n+20]==1&ifscode[_n+20]==144)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c144=wt144 if (crisis[_n+21]==1&ifscode[_n+21]==144)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c146=0

replace c146=wt146 if (crisis[_n-1]==1&ifscode[_n-1]==146)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c146=wt146 if (crisis[_n-2]==1&ifscode[_n-2]==146)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c146=wt146 if (crisis[_n-3]==1&ifscode[_n-3]==146)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c146=wt146 if (crisis[_n-4]==1&ifscode[_n-4]==146)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c146=wt146 if (crisis[_n-5]==1&ifscode[_n-5]==146)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c146=wt146 if (crisis[_n-6]==1&ifscode[_n-6]==146)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c146=wt146 if (crisis[_n-7]==1&ifscode[_n-7]==146)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c146=wt146 if (crisis[_n-8]==1&ifscode[_n-8]==146)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c146=wt146 if (crisis[_n-9]==1&ifscode[_n-9]==146)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c146=wt146 if (crisis[_n-10]==1&ifscode[_n-10]==146)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c146=wt146 if (crisis[_n-11]==1&ifscode[_n-11]==146)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c146=wt146 if (crisis[_n-12]==1&ifscode[_n-12]==146)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c146=wt146 if (crisis[_n-13]==1&ifscode[_n-13]==146)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c146=wt146 if (crisis[_n-14]==1&ifscode[_n-14]==146)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c146=wt146 if (crisis[_n-15]==1&ifscode[_n-15]==146)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c146=wt146 if (crisis[_n-16]==1&ifscode[_n-16]==146)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c146=wt146 if (crisis[_n-17]==1&ifscode[_n-17]==146)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c146=wt146 if (crisis[_n-18]==1&ifscode[_n-18]==146)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c146=wt146 if (crisis[_n-19]==1&ifscode[_n-19]==146)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c146=wt146 if (crisis[_n-20]==1&ifscode[_n-20]==146)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c146=wt146 if (crisis[_n-21]==1&ifscode[_n-21]==146)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c146=wt146 if (crisis[_n+1]==1&ifscode[_n+1]==146)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c146=wt146 if (crisis[_n+2]==1&ifscode[_n+2]==146)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c146=wt146 if (crisis[_n+3]==1&ifscode[_n+3]==146)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c146=wt146 if (crisis[_n+4]==1&ifscode[_n+4]==146)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c146=wt146 if (crisis[_n+5]==1&ifscode[_n+5]==146)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c146=wt146 if (crisis[_n+6]==1&ifscode[_n+6]==146)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c146=wt146 if (crisis[_n+7]==1&ifscode[_n+7]==146)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c146=wt146 if (crisis[_n+8]==1&ifscode[_n+8]==146)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c146=wt146 if (crisis[_n+9]==1&ifscode[_n+9]==146)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c146=wt146 if (crisis[_n+10]==1&ifscode[_n+10]==146)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c146=wt146 if (crisis[_n+11]==1&ifscode[_n+11]==146)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c146=wt146 if (crisis[_n+12]==1&ifscode[_n+12]==146)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c146=wt146 if (crisis[_n+13]==1&ifscode[_n+13]==146)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c146=wt146 if (crisis[_n+14]==1&ifscode[_n+14]==146)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c146=wt146 if (crisis[_n+15]==1&ifscode[_n+15]==146)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c146=wt146 if (crisis[_n+16]==1&ifscode[_n+16]==146)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c146=wt146 if (crisis[_n+17]==1&ifscode[_n+17]==146)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c146=wt146 if (crisis[_n+18]==1&ifscode[_n+18]==146)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c146=wt146 if (crisis[_n+19]==1&ifscode[_n+19]==146)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c146=wt146 if (crisis[_n+20]==1&ifscode[_n+20]==146)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c146=wt146 if (crisis[_n+21]==1&ifscode[_n+21]==146)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c112=0

replace c112=wt112 if (crisis[_n-1]==1&ifscode[_n-1]==112)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c112=wt112 if (crisis[_n-2]==1&ifscode[_n-2]==112)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c112=wt112 if (crisis[_n-3]==1&ifscode[_n-3]==112)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c112=wt112 if (crisis[_n-4]==1&ifscode[_n-4]==112)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c112=wt112 if (crisis[_n-5]==1&ifscode[_n-5]==112)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c112=wt112 if (crisis[_n-6]==1&ifscode[_n-6]==112)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c112=wt112 if (crisis[_n-7]==1&ifscode[_n-7]==112)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c112=wt112 if (crisis[_n-8]==1&ifscode[_n-8]==112)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c112=wt112 if (crisis[_n-9]==1&ifscode[_n-9]==112)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c112=wt112 if (crisis[_n-10]==1&ifscode[_n-10]==112)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c112=wt112 if (crisis[_n-11]==1&ifscode[_n-11]==112)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c112=wt112 if (crisis[_n-12]==1&ifscode[_n-12]==112)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c112=wt112 if (crisis[_n-13]==1&ifscode[_n-13]==112)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c112=wt112 if (crisis[_n-14]==1&ifscode[_n-14]==112)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c112=wt112 if (crisis[_n-15]==1&ifscode[_n-15]==112)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c112=wt112 if (crisis[_n-16]==1&ifscode[_n-16]==112)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c112=wt112 if (crisis[_n-17]==1&ifscode[_n-17]==112)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c112=wt112 if (crisis[_n-18]==1&ifscode[_n-18]==112)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c112=wt112 if (crisis[_n-19]==1&ifscode[_n-19]==112)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c112=wt112 if (crisis[_n-20]==1&ifscode[_n-20]==112)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c112=wt112 if (crisis[_n-21]==1&ifscode[_n-21]==112)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c112=wt112 if (crisis[_n+1]==1&ifscode[_n+1]==112)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c112=wt112 if (crisis[_n+2]==1&ifscode[_n+2]==112)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c112=wt112 if (crisis[_n+3]==1&ifscode[_n+3]==112)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c112=wt112 if (crisis[_n+4]==1&ifscode[_n+4]==112)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c112=wt112 if (crisis[_n+5]==1&ifscode[_n+5]==112)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c112=wt112 if (crisis[_n+6]==1&ifscode[_n+6]==112)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c112=wt112 if (crisis[_n+7]==1&ifscode[_n+7]==112)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c112=wt112 if (crisis[_n+8]==1&ifscode[_n+8]==112)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c112=wt112 if (crisis[_n+9]==1&ifscode[_n+9]==112)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c112=wt112 if (crisis[_n+10]==1&ifscode[_n+10]==112)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c112=wt112 if (crisis[_n+11]==1&ifscode[_n+11]==112)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c112=wt112 if (crisis[_n+12]==1&ifscode[_n+12]==112)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c112=wt112 if (crisis[_n+13]==1&ifscode[_n+13]==112)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c112=wt112 if (crisis[_n+14]==1&ifscode[_n+14]==112)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c112=wt112 if (crisis[_n+15]==1&ifscode[_n+15]==112)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c112=wt112 if (crisis[_n+16]==1&ifscode[_n+16]==112)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c112=wt112 if (crisis[_n+17]==1&ifscode[_n+17]==112)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c112=wt112 if (crisis[_n+18]==1&ifscode[_n+18]==112)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c112=wt112 if (crisis[_n+19]==1&ifscode[_n+19]==112)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c112=wt112 if (crisis[_n+20]==1&ifscode[_n+20]==112)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c112=wt112 if (crisis[_n+21]==1&ifscode[_n+21]==112)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g c111=0

replace c111=wt111 if (crisis[_n-1]==1&ifscode[_n-1]==111)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
replace c111=wt111 if (crisis[_n-2]==1&ifscode[_n-2]==111)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
replace c111=wt111 if (crisis[_n-3]==1&ifscode[_n-3]==111)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
replace c111=wt111 if (crisis[_n-4]==1&ifscode[_n-4]==111)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
replace c111=wt111 if (crisis[_n-5]==1&ifscode[_n-5]==111)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
replace c111=wt111 if (crisis[_n-6]==1&ifscode[_n-6]==111)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
replace c111=wt111 if (crisis[_n-7]==1&ifscode[_n-7]==111)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
replace c111=wt111 if (crisis[_n-8]==1&ifscode[_n-8]==111)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
replace c111=wt111 if (crisis[_n-9]==1&ifscode[_n-9]==111)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
replace c111=wt111 if (crisis[_n-10]==1&ifscode[_n-10]==111)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
replace c111=wt111 if (crisis[_n-11]==1&ifscode[_n-11]==111)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
replace c111=wt111 if (crisis[_n-12]==1&ifscode[_n-12]==111)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
replace c111=wt111 if (crisis[_n-13]==1&ifscode[_n-13]==111)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
replace c111=wt111 if (crisis[_n-14]==1&ifscode[_n-14]==111)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
replace c111=wt111 if (crisis[_n-15]==1&ifscode[_n-15]==111)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
replace c111=wt111 if (crisis[_n-16]==1&ifscode[_n-16]==111)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
replace c111=wt111 if (crisis[_n-17]==1&ifscode[_n-17]==111)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
replace c111=wt111 if (crisis[_n-18]==1&ifscode[_n-18]==111)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
replace c111=wt111 if (crisis[_n-19]==1&ifscode[_n-19]==111)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
replace c111=wt111 if (crisis[_n-20]==1&ifscode[_n-20]==111)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
replace c111=wt111 if (crisis[_n-21]==1&ifscode[_n-21]==111)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

replace c111=wt111 if (crisis[_n+1]==1&ifscode[_n+1]==111)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
replace c111=wt111 if (crisis[_n+2]==1&ifscode[_n+2]==111)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
replace c111=wt111 if (crisis[_n+3]==1&ifscode[_n+3]==111)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
replace c111=wt111 if (crisis[_n+4]==1&ifscode[_n+4]==111)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
replace c111=wt111 if (crisis[_n+5]==1&ifscode[_n+5]==111)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
replace c111=wt111 if (crisis[_n+6]==1&ifscode[_n+6]==111)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
replace c111=wt111 if (crisis[_n+7]==1&ifscode[_n+7]==111)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
replace c111=wt111 if (crisis[_n+8]==1&ifscode[_n+8]==111)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
replace c111=wt111 if (crisis[_n+9]==1&ifscode[_n+9]==111)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
replace c111=wt111 if (crisis[_n+10]==1&ifscode[_n+10]==111)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
replace c111=wt111 if (crisis[_n+11]==1&ifscode[_n+11]==111)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
replace c111=wt111 if (crisis[_n+12]==1&ifscode[_n+12]==111)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
replace c111=wt111 if (crisis[_n+13]==1&ifscode[_n+13]==111)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
replace c111=wt111 if (crisis[_n+14]==1&ifscode[_n+14]==111)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
replace c111=wt111 if (crisis[_n+15]==1&ifscode[_n+15]==111)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
replace c111=wt111 if (crisis[_n+16]==1&ifscode[_n+16]==111)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
replace c111=wt111 if (crisis[_n+17]==1&ifscode[_n+17]==111)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
replace c111=wt111 if (crisis[_n+18]==1&ifscode[_n+18]==111)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
replace c111=wt111 if (crisis[_n+19]==1&ifscode[_n+19]==111)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
replace c111=wt111 if (crisis[_n+20]==1&ifscode[_n+20]==111)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
replace c111=wt111 if (crisis[_n+21]==1&ifscode[_n+21]==111)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

g crisisw=c193+c122+c126+c156+c128+c172+c132+c134+c174+c178+c136+c158+c138+c196+c142+c182+c184+c144+c146+c112+c111

sort ifscode date
*
* Create capital controls lags
*
g byte kalg2=0
quietly replace kalg2=1 if (ka[_n-1]==1|ka[_n-2]==1)&ifscode==ifscode[_n-2]
g byte kalg4=0
quietly replace kalg4=1 if ((ka[_n-1]==1|ka[_n-2]==1)|(ka[_n-3]==1|ka[_n-4]==1))&ifscode==ifscode[_n-4]
g byte kalg8=0
quietly replace kalg8=1 if (((ka[_n-1]==1|ka[_n-2]==1)|(ka[_n-3]==1|ka[_n-4]==1))&((ka[_n-5]==1|ka[_n-6]==1)|(ka[_n-7]==1|ka[_n-8]==1)))&ifscode==ifscode[_n-8]

g c2ka=((1./3)*ka)+((2./3.)*kalg2)
g c4ka=((1./5)*ka)+((4./5.)*kalg4)
g c8ka=((1./9)*ka)+((8./9.)*kalg8)
*
* Generate the regressors: Typically log-differences, domestic minus center
*
g dlcredit=100.*((log(ifs32)-log(ifs32[_n-4]))-(log(gifs32)-log(gifs32[_n-4]))) if ifscode==ifscode[_n-4]
g lag8crd=(1./8.)*(dlcredit[_n-1]+dlcredit[_n-2]+dlcredit[_n-3]+dlcredit[_n-4]+dlcredit[_n-5]+dlcredit[_n-6]+dlcredit[_n-7]+dlcredit[_n-8]) if ifscode==ifscode[_n-8]
g lag4crd=(1./4.)*(dlcredit[_n-1]+dlcredit[_n-2]+dlcredit[_n-3]+dlcredit[_n-4]) if ifscode==ifscode[_n-4]
g lag2crd=(1./2.)*(dlcredit[_n-1]+dlcredit[_n-2]) if ifscode==ifscode[_n-2]

g c2crd=((1./3)*dlcredit)+((2./3.)*lag2crd)
g c4crd=((1./5)*dlcredit)+((4./5.)*lag4crd)
g c8crd=((1./9)*dlcredit)+((8./9.)*lag8crd)

g dlm1=100.*((log(ifs34)-log(ifs34[_n-4]))-(log(gifs34)-log(gifs34[_n-4]))) if ifscode==ifscode[_n-4]
g lag8lm1=(1./8.)*(dlm1[_n-1]+dlm1[_n-2]+dlm1[_n-3]+dlm1[_n-4]+dlm1[_n-5]+dlm1[_n-6]+dlm1[_n-7]+dlm1[_n-8]) if ifscode==ifscode[_n-8]
g lag4lm1=(1./4.)*(dlm1[_n-1]+dlm1[_n-2]+dlm1[_n-3]+dlm1[_n-4]) if ifscode==ifscode[_n-4]
g lag2lm1=(1./2.)*(dlm1[_n-1]+dlm1[_n-2]) if ifscode==ifscode[_n-2]

g c2lm1=((1./3)*dlm1)+((2./3.)*lag2lm1)
g c4lm1=((1./5)*dlm1)+((4./5.)*lag4lm1)
g c8lm1=((1./9)*dlm1)+((8./9.)*lag8lm1)

g dlongi=ifs61-gifs61
g lag8lngi=(1./8.)*(dlongi[_n-1]+dlongi[_n-2]+dlongi[_n-3]+dlongi[_n-4]+dlongi[_n-5]+dlongi[_n-6]+dlongi[_n-7]+dlongi[_n-8]) if ifscode==ifscode[_n-8]
g lag4lngi=(1./4.)*(dlongi[_n-1]+dlongi[_n-2]+dlongi[_n-3]+dlongi[_n-4]) if ifscode==ifscode[_n-4]
g lag2lngi=(1./2.)*(dlongi[_n-1]+dlongi[_n-2]) if ifscode==ifscode[_n-2]

g c2lngi=((1./3)*dlongi)+((2./3.)*lag2lngi)
g c4lngi=((1./5)*dlongi)+((4./5.)*lag4lngi)
g c8lngi=((1./9)*dlongi)+((8./9.)*lag8lngi)

g dlprice=100.*((log(ifs64)-log(ifs64[_n-4]))-(log(gifs64)-log(gifs64[_n-4]))) if ifscode==ifscode[_n-4]
g lag8pri=(1./8.)*(dlprice[_n-1]+dlprice[_n-2]+dlprice[_n-3]+dlprice[_n-4]+dlprice[_n-5]+dlprice[_n-6]+dlprice[_n-7]+dlprice[_n-8]) if ifscode==ifscode[_n-8]
g lag4pri=(1./4.)*(dlprice[_n-1]+dlprice[_n-2]+dlprice[_n-3]+dlprice[_n-4]) if ifscode==ifscode[_n-4]
g lag2pri=(1./2.)*(dlprice[_n-1]+dlprice[_n-2]) if ifscode==ifscode[_n-2]

g c2pri=((1./3)*dlprice)+((2./3.)*lag2pri)
g c4pri=((1./5)*dlprice)+((4./5.)*lag4pri)
g c8pri=((1./9)*dlprice)+((8./9.)*lag8pri)

g dlrealy=100.*((log(ifs99)-log(ifs99[_n-4]))-(log(gifs99)-log(gifs99[_n-4]))) if ifscode==ifscode[_n-4]
g lag8rly=(1./8.)*(dlrealy[_n-1]+dlrealy[_n-2]+dlrealy[_n-3]+dlrealy[_n-4]+dlrealy[_n-5]+dlrealy[_n-6]+dlrealy[_n-7]+dlrealy[_n-8]) if ifscode==ifscode[_n-8]
g lag4rly=(1./4.)*(dlrealy[_n-1]+dlrealy[_n-2]+dlrealy[_n-3]+dlrealy[_n-4]) if ifscode==ifscode[_n-4]
g lag2rly=(1./2.)*(dlrealy[_n-1]+dlrealy[_n-2]) if ifscode==ifscode[_n-2]

g c2rly=((1./3)*dlrealy)+((2./3.)*lag2rly)
g c4rly=((1./5)*dlrealy)+((4./5.)*lag4rly)
g c8rly=((1./9)*dlrealy)+((8./9.)*lag8rly)

g dlwage=100.*((log(wr)-log(wr[_n-4]))-(log(gwr)-log(gwr[_n-4]))) if ifscode==ifscode[_n-4]
g lag8wag=(1./8.)*(dlwage[_n-1]+dlwage[_n-2]+dlwage[_n-3]+dlwage[_n-4]+dlwage[_n-5]+dlwage[_n-6]+dlwage[_n-7]+dlwage[_n-8]) if ifscode==ifscode[_n-8]
g lag4wag=(1./4.)*(dlwage[_n-1]+dlwage[_n-2]+dlwage[_n-3]+dlwage[_n-4]) if ifscode==ifscode[_n-4]
g lag2wag=(1./2.)*(dlwage[_n-1]+dlwage[_n-2]) if ifscode==ifscode[_n-2]

g c2wag=((1./3)*dlwage)+((2./3.)*lag2wag)
g c4wag=((1./5)*dlwage)+((4./5.)*lag4wag)
g c8wag=((1./9)*dlwage)+((8./9.)*lag8wag)

g dlemploy=100.*((log(et)-log(et[_n-4]))-(log(get)-log(get[_n-4]))) if ifscode==ifscode[_n-4]
g lag8emp=(1./8.)*(dlemploy[_n-1]+dlemploy[_n-2]+dlemploy[_n-3]+dlemploy[_n-4]+dlemploy[_n-5]+dlemploy[_n-6]+dlemploy[_n-7]+dlemploy[_n-8]) if ifscode==ifscode[_n-8]
g lag4emp=(1./4.)*(dlemploy[_n-1]+dlemploy[_n-2]+dlemploy[_n-3]+dlemploy[_n-4]) if ifscode==ifscode[_n-4]
g lag2emp=(1./2.)*(dlemploy[_n-1]+dlemploy[_n-2]) if ifscode==ifscode[_n-2]

g c2emp=((1./3)*dlemploy)+((2./3.)*lag2emp)
g c4emp=((1./5)*dlemploy)+((4./5.)*lag4emp)
g c8emp=((1./9)*dlemploy)+((8./9.)*lag8emp)

g dunr=unr-gunr
g lag8unr=(1./8.)*(dunr[_n-1]+dunr[_n-2]+dunr[_n-3]+dunr[_n-4]+dunr[_n-5]+dunr[_n-6]+dunr[_n-7]+dunr[_n-8]) if ifscode==ifscode[_n-8]
g lag4unr=(1./4.)*(dunr[_n-1]+dunr[_n-2]+dunr[_n-3]+dunr[_n-4]) if ifscode==ifscode[_n-4]
g lag2unr=(1./2.)*(dunr[_n-1]+dunr[_n-2]) if ifscode==ifscode[_n-2]

g c2unr=((1./3)*dunr)+((2./3.)*lag2unr)
g c4unr=((1./5)*dunr)+((4./5.)*lag4unr)
g c8unr=((1./9)*dunr)+((8./9.)*lag8unr)

g dlexprt=100.*((log(ifs70d)-log(ifs70d[_n-4]))-(log(gifs70d)-log(gifs70d[_n-4]))) if ifscode==ifscode[_n-4]
g lag8exp=(1./8.)*(dlexprt[_n-1]+dlexprt[_n-2]+dlexprt[_n-3]+dlexprt[_n-4]+dlexprt[_n-5]+dlexprt[_n-6]+dlexprt[_n-7]+dlexprt[_n-8]) if ifscode==ifscode[_n-8]
g lag4exp=(1./4.)*(dlexprt[_n-1]+dlexprt[_n-2]+dlexprt[_n-3]+dlexprt[_n-4]) if ifscode==ifscode[_n-4]
g lag2exp=(1./2.)*(dlexprt[_n-1]+dlexprt[_n-2]) if ifscode==ifscode[_n-2]

g c2exp=((1./3)*dlexprt)+((2./3.)*lag2exp)
g c4exp=((1./5)*dlexprt)+((4./5.)*lag4exp)
g c8exp=((1./9)*dlexprt)+((8./9.)*lag8exp)

g dlimprt=100.*((log(ifs71d)-log(ifs71d[_n-4]))-(log(gifs71d)-log(gifs71d[_n-4]))) if ifscode==ifscode[_n-4]
g lag8imp=(1./8.)*(dlimprt[_n-1]+dlimprt[_n-2]+dlimprt[_n-3]+dlimprt[_n-4]+dlimprt[_n-5]+dlimprt[_n-6]+dlimprt[_n-7]+dlimprt[_n-8]) if ifscode==ifscode[_n-8]
g lag4imp=(1./4.)*(dlimprt[_n-1]+dlimprt[_n-2]+dlimprt[_n-3]+dlimprt[_n-4]) if ifscode==ifscode[_n-4]
g lag2imp=(1./2.)*(dlimprt[_n-1]+dlimprt[_n-2]) if ifscode==ifscode[_n-2]

g c2imp=((1./3)*dlimprt)+((2./3.)*lag2imp)
g c4imp=((1./5)*dlimprt)+((4./5.)*lag4imp)
g c8imp=((1./9)*dlimprt)+((8./9.)*lag8imp)

g dcacc=cacc-gcacc
g lag8cac=(1./8.)*(dcacc[_n-1]+dcacc[_n-2]+dcacc[_n-3]+dcacc[_n-4]+dcacc[_n-5]+dcacc[_n-6]+dcacc[_n-7]+dcacc[_n-8]) if ifscode==ifscode[_n-8]
g lag4cac=(1./4.)*(dcacc[_n-1]+dcacc[_n-2]+dcacc[_n-3]+dcacc[_n-4]) if ifscode==ifscode[_n-4]
g lag2cac=(1./2.)*(dcacc[_n-1]+dcacc[_n-2]) if ifscode==ifscode[_n-2]

g c2cac=((1./3)*dcacc)+((2./3.)*lag2cac)
g c4cac=((1./5)*dcacc)+((4./5.)*lag4cac)
g c8cac=((1./9)*dcacc)+((8./9.)*lag8cac)

g dbudget=budg-gbudg
g lag8bud=(1./8.)*(dbudget[_n-1]+dbudget[_n-2]+dbudget[_n-3]+dbudget[_n-4]+dbudget[_n-5]+dbudget[_n-6]+dbudget[_n-7]+dbudget[_n-8]) if ifscode==ifscode[_n-8]
g lag4bud=(1./4.)*(dbudget[_n-1]+dbudget[_n-2]+dbudget[_n-3]+dbudget[_n-4]) if ifscode==ifscode[_n-4]
g lag2bud=(1./2.)*(dbudget[_n-1]+dbudget[_n-2]) if ifscode==ifscode[_n-2]

g c2bud=((1./3)*dbudget)+((2./3.)*lag2bud)
g c4bud=((1./5)*dbudget)+((4./5.)*lag4bud)
g c8bud=((1./9)*dbudget)+((8./9.)*lag8bud)
*
* Generate the political regressors
*
g byte govtvict=0
quietly replace govtvict=1 if election==1&dregime==2
g byte govtloss=0
quietly replace govtloss=1 if election==1&dregime==1
quietly replace govtloss=1 if election==2&dregime==1

g gv8lag=0
quietly replace gv8lag=1 if ((govtvict[_n-1]+govtvict[_n-2]+govtvict[_n-3]+govtvict[_n-4]+govtvict[_n-5]+govtvict[_n-6]+govtvict[_n-7]+govtvict[_n-8])>.5)&(ifscode==ifscode[_n-8])
g gv4lag=0
quietly replace gv4lag=1 if ((govtvict[_n-1]+govtvict[_n-2]+govtvict[_n-3]+govtvict[_n-4])>.5)&(ifscode==ifscode[_n-4])
g gv2lag=0
quietly replace gv2lag=1 if ((govtvict[_n-1]+govtvict[_n-2])>.5)&(ifscode==ifscode[_n-2])

g gl8lag=0
quietly replace gl8lag=1 if ((govtloss[_n-1]+govtloss[_n-2]+govtloss[_n-3]+govtloss[_n-4]+govtloss[_n-5]+govtloss[_n-6]+govtloss[_n-7]+govtloss[_n-8])>.5)&(ifscode==ifscode[_n-8])
g gl4lag=0
quietly replace gl4lag=1 if ((govtloss[_n-1]+govtloss[_n-2]+govtloss[_n-3]+govtloss[_n-4])>.5)&(ifscode==ifscode[_n-4])
g gl2lag=0
quietly replace gl2lag=1 if ((govtloss[_n-1]+govtloss[_n-2])>.5)&(ifscode==ifscode[_n-2])

g c2gv=((1./3)*govtvict)+((2./3.)*gv2lag)
g c4gv=((1./5)*govtvict)+((4./5.)*gv4lag)
g c8gv=((1./9)*govtvict)+((8./9.)*gv8lag)

g c2gl=((1./3)*govtloss)+((2./3.)*gl2lag)
g c4gl=((1./5)*govtloss)+((4./5.)*gl4lag)
g c8gl=((1./9)*govtloss)+((8./9.)*gl8lag)

compress
*
* Create the weights for the crisis measures.
*
* These weights are country-specific
*
* Create first means, then standard deviations
*
sort ifscode date10

egen wcim=mean(dlcredit), by(ifscode)
egen wmim=mean(dlm1), by(ifscode)
egen wpim=mean(dlprice), by(ifscode)
egen wyim=mean(dlrealy), by(ifscode)
egen wuim=mean(dunr), by(ifscode)
egen wtim=mean(dcacc), by(ifscode)
egen wbim=mean(dbudget), by(ifscode)

egen wcis=sd(dlcredit), by(ifscode)
egen wmis=sd(dlm1), by(ifscode)
egen wpis=sd(dlprice), by(ifscode)
egen wyis=sd(dlrealy), by(ifscode)
egen wuis=sd(dunr), by(ifscode)
egen wtis=sd(dcacc), by(ifscode)
egen wbis=sd(dbudget), by(ifscode)
*
* And now the actual standardized variables
*
g wci=(dlcredit-wcim)/wcis
g wmi=(dlm1-wmim)/wmis
g wpi=(dlprice-wpim)/wpis
g wui=(dunr-wuim)/wuis
*
* (With a Negative Transformation to make higher values "worse")
*
g wti=-(dcacc-wtim)/wtis
g wbi=-(dbudget-wbim)/wbis
g wyi=-(dlrealy-wyim)/wyis

drop wcim-wbis
*
* These weights are time-specific
*
* Create first means, then standard deviations
*
sort ifscode date10

egen wctm=mean(dlcredit), by(date10)
egen wmtm=mean(dlm1), by(date10)
egen wptm=mean(dlprice), by(date10)
egen wytm=mean(dlrealy), by(date10)
egen wutm=mean(dunr), by(date10)
egen wttm=mean(dcacc), by(date10)
egen wbtm=mean(dbudget), by(date10)

egen wcts=sd(dlcredit), by(date10)
egen wmts=sd(dlm1), by(date10)
egen wpts=sd(dlprice), by(date10)
egen wyts=sd(dlrealy), by(date10)
egen wuts=sd(dunr), by(date10)
egen wtts=sd(dcacc), by(date10)
egen wbts=sd(dbudget), by(date10)
*
* And now the actual standardized variables
*
g wct=(dlcredit-wctm)/wcts
g wmt=(dlm1-wmtm)/wmts
g wpt=(dlprice-wptm)/wpts
g wut=(dunr-wutm)/wuts
*
* (With a Negative Transformation to make higher values "worse")
*
g wtt=-(dcacc-wttm)/wtts
g wbt=-(dbudget-wbtm)/wbts
g wyt=-(dlrealy-wytm)/wyts

drop wctm-wbts

sort date10 ifscode
*
* Now created the weighted crisis measures
*
sum wci-wbi
sum wct-wbt
*
* The variable is c, the averaging is done via method i
*
quietly g crcim1=1-(normprob(wci[_n-1])-normprob(wci)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g crcim2=1-(normprob(wci[_n-2])-normprob(wci)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g crcim3=1-(normprob(wci[_n-3])-normprob(wci)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g crcim4=1-(normprob(wci[_n-4])-normprob(wci)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g crcim5=1-(normprob(wci[_n-5])-normprob(wci)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g crcim6=1-(normprob(wci[_n-6])-normprob(wci)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g crcim7=1-(normprob(wci[_n-7])-normprob(wci)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g crcim8=1-(normprob(wci[_n-8])-normprob(wci)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g crcim9=1-(normprob(wci[_n-9])-normprob(wci)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g crcim10=1-(normprob(wci[_n-10])-normprob(wci)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g crcim11=1-(normprob(wci[_n-11])-normprob(wci)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g crcim12=1-(normprob(wci[_n-12])-normprob(wci)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g crcim13=1-(normprob(wci[_n-13])-normprob(wci)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g crcim14=1-(normprob(wci[_n-14])-normprob(wci)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g crcim15=1-(normprob(wci[_n-15])-normprob(wci)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g crcim16=1-(normprob(wci[_n-16])-normprob(wci)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g crcim17=1-(normprob(wci[_n-17])-normprob(wci)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g crcim18=1-(normprob(wci[_n-18])-normprob(wci)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g crcim19=1-(normprob(wci[_n-19])-normprob(wci)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g crcim20=1-(normprob(wci[_n-20])-normprob(wci)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g crcim21=1-(normprob(wci[_n-21])-normprob(wci)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g crcip1=1-(normprob(wci[_n+1])-normprob(wci)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g crcip2=1-(normprob(wci[_n+2])-normprob(wci)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g crcip3=1-(normprob(wci[_n+3])-normprob(wci)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g crcip4=1-(normprob(wci[_n+4])-normprob(wci)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g crcip5=1-(normprob(wci[_n+5])-normprob(wci)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g crcip6=1-(normprob(wci[_n+6])-normprob(wci)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g crcip7=1-(normprob(wci[_n+7])-normprob(wci)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g crcip8=1-(normprob(wci[_n+8])-normprob(wci)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g crcip9=1-(normprob(wci[_n+9])-normprob(wci)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g crcip10=1-(normprob(wci[_n+10])-normprob(wci)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g crcip11=1-(normprob(wci[_n+11])-normprob(wci)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g crcip12=1-(normprob(wci[_n+12])-normprob(wci)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g crcip13=1-(normprob(wci[_n+13])-normprob(wci)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g crcip14=1-(normprob(wci[_n+14])-normprob(wci)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g crcip15=1-(normprob(wci[_n+15])-normprob(wci)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g crcip16=1-(normprob(wci[_n+16])-normprob(wci)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g crcip17=1-(normprob(wci[_n+17])-normprob(wci)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g crcip18=1-(normprob(wci[_n+18])-normprob(wci)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g crcip19=1-(normprob(wci[_n+19])-normprob(wci)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g crcip20=1-(normprob(wci[_n+20])-normprob(wci)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g crcip21=1-(normprob(wci[_n+21])-normprob(wci)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswci=0

quietly replace criswci=criswci+crcim1 if crcim1~=.
quietly replace criswci=criswci+crcim2 if crcim2~=.
quietly replace criswci=criswci+crcim3 if crcim3~=.
quietly replace criswci=criswci+crcim4 if crcim4~=.
quietly replace criswci=criswci+crcim5 if crcim5~=.
quietly replace criswci=criswci+crcim6 if crcim6~=.
quietly replace criswci=criswci+crcim7 if crcim7~=.
quietly replace criswci=criswci+crcim8 if crcim8~=.
quietly replace criswci=criswci+crcim9 if crcim9~=.
quietly replace criswci=criswci+crcim10 if crcim10~=.
quietly replace criswci=criswci+crcim11 if crcim11~=.
quietly replace criswci=criswci+crcim12 if crcim12~=.
quietly replace criswci=criswci+crcim13 if crcim13~=.
quietly replace criswci=criswci+crcim14 if crcim14~=.
quietly replace criswci=criswci+crcim15 if crcim15~=.
quietly replace criswci=criswci+crcim16 if crcim16~=.
quietly replace criswci=criswci+crcim17 if crcim17~=.
quietly replace criswci=criswci+crcim18 if crcim18~=.
quietly replace criswci=criswci+crcim19 if crcim19~=.
quietly replace criswci=criswci+crcim20 if crcim20~=.
quietly replace criswci=criswci+crcim21 if crcim21~=.
quietly replace criswci=criswci+crcip1 if crcip1~=.
quietly replace criswci=criswci+crcip2 if crcip2~=.
quietly replace criswci=criswci+crcip3 if crcip3~=.
quietly replace criswci=criswci+crcip4 if crcip4~=.
quietly replace criswci=criswci+crcip5 if crcip5~=.
quietly replace criswci=criswci+crcip6 if crcip6~=.
quietly replace criswci=criswci+crcip7 if crcip7~=.
quietly replace criswci=criswci+crcip8 if crcip8~=.
quietly replace criswci=criswci+crcip9 if crcip9~=.
quietly replace criswci=criswci+crcip10 if crcip10~=.
quietly replace criswci=criswci+crcip11 if crcip11~=.
quietly replace criswci=criswci+crcip12 if crcip12~=.
quietly replace criswci=criswci+crcip13 if crcip13~=.
quietly replace criswci=criswci+crcip14 if crcip14~=.
quietly replace criswci=criswci+crcip15 if crcip15~=.
quietly replace criswci=criswci+crcip16 if crcip16~=.
quietly replace criswci=criswci+crcip17 if crcip17~=.
quietly replace criswci=criswci+crcip18 if crcip18~=.
quietly replace criswci=criswci+crcip19 if crcip19~=.
quietly replace criswci=criswci+crcip20 if crcip20~=.
quietly replace criswci=criswci+crcip21 if crcip21~=.

drop crcim1-crcim21
drop crcip1-crcip21
*
* The variable is m, the averaging is done via method i
*
quietly g crmim1=1-(normprob(wmi[_n-1])-normprob(wmi)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g crmim2=1-(normprob(wmi[_n-2])-normprob(wmi)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g crmim3=1-(normprob(wmi[_n-3])-normprob(wmi)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g crmim4=1-(normprob(wmi[_n-4])-normprob(wmi)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g crmim5=1-(normprob(wmi[_n-5])-normprob(wmi)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g crmim6=1-(normprob(wmi[_n-6])-normprob(wmi)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g crmim7=1-(normprob(wmi[_n-7])-normprob(wmi)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g crmim8=1-(normprob(wmi[_n-8])-normprob(wmi)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g crmim9=1-(normprob(wmi[_n-9])-normprob(wmi)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g crmim10=1-(normprob(wmi[_n-10])-normprob(wmi)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g crmim11=1-(normprob(wmi[_n-11])-normprob(wmi)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g crmim12=1-(normprob(wmi[_n-12])-normprob(wmi)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g crmim13=1-(normprob(wmi[_n-13])-normprob(wmi)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g crmim14=1-(normprob(wmi[_n-14])-normprob(wmi)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g crmim15=1-(normprob(wmi[_n-15])-normprob(wmi)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g crmim16=1-(normprob(wmi[_n-16])-normprob(wmi)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g crmim17=1-(normprob(wmi[_n-17])-normprob(wmi)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g crmim18=1-(normprob(wmi[_n-18])-normprob(wmi)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g crmim19=1-(normprob(wmi[_n-19])-normprob(wmi)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g crmim20=1-(normprob(wmi[_n-20])-normprob(wmi)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g crmim21=1-(normprob(wmi[_n-21])-normprob(wmi)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g crmip1=1-(normprob(wmi[_n+1])-normprob(wmi)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g crmip2=1-(normprob(wmi[_n+2])-normprob(wmi)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g crmip3=1-(normprob(wmi[_n+3])-normprob(wmi)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g crmip4=1-(normprob(wmi[_n+4])-normprob(wmi)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g crmip5=1-(normprob(wmi[_n+5])-normprob(wmi)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g crmip6=1-(normprob(wmi[_n+6])-normprob(wmi)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g crmip7=1-(normprob(wmi[_n+7])-normprob(wmi)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g crmip8=1-(normprob(wmi[_n+8])-normprob(wmi)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g crmip9=1-(normprob(wmi[_n+9])-normprob(wmi)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g crmip10=1-(normprob(wmi[_n+10])-normprob(wmi)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g crmip11=1-(normprob(wmi[_n+11])-normprob(wmi)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g crmip12=1-(normprob(wmi[_n+12])-normprob(wmi)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g crmip13=1-(normprob(wmi[_n+13])-normprob(wmi)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g crmip14=1-(normprob(wmi[_n+14])-normprob(wmi)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g crmip15=1-(normprob(wmi[_n+15])-normprob(wmi)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g crmip16=1-(normprob(wmi[_n+16])-normprob(wmi)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g crmip17=1-(normprob(wmi[_n+17])-normprob(wmi)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g crmip18=1-(normprob(wmi[_n+18])-normprob(wmi)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g crmip19=1-(normprob(wmi[_n+19])-normprob(wmi)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g crmip20=1-(normprob(wmi[_n+20])-normprob(wmi)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g crmip21=1-(normprob(wmi[_n+21])-normprob(wmi)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswmi=0

quietly replace criswmi=criswmi+crmim1 if crmim1~=.
quietly replace criswmi=criswmi+crmim2 if crmim2~=.
quietly replace criswmi=criswmi+crmim3 if crmim3~=.
quietly replace criswmi=criswmi+crmim4 if crmim4~=.
quietly replace criswmi=criswmi+crmim5 if crmim5~=.
quietly replace criswmi=criswmi+crmim6 if crmim6~=.
quietly replace criswmi=criswmi+crmim7 if crmim7~=.
quietly replace criswmi=criswmi+crmim8 if crmim8~=.
quietly replace criswmi=criswmi+crmim9 if crmim9~=.
quietly replace criswmi=criswmi+crmim10 if crmim10~=.
quietly replace criswmi=criswmi+crmim11 if crmim11~=.
quietly replace criswmi=criswmi+crmim12 if crmim12~=.
quietly replace criswmi=criswmi+crmim13 if crmim13~=.
quietly replace criswmi=criswmi+crmim14 if crmim14~=.
quietly replace criswmi=criswmi+crmim15 if crmim15~=.
quietly replace criswmi=criswmi+crmim16 if crmim16~=.
quietly replace criswmi=criswmi+crmim17 if crmim17~=.
quietly replace criswmi=criswmi+crmim18 if crmim18~=.
quietly replace criswmi=criswmi+crmim19 if crmim19~=.
quietly replace criswmi=criswmi+crmim20 if crmim20~=.
quietly replace criswmi=criswmi+crmim21 if crmim21~=.
quietly replace criswmi=criswmi+crmip1 if crmip1~=.
quietly replace criswmi=criswmi+crmip2 if crmip2~=.
quietly replace criswmi=criswmi+crmip3 if crmip3~=.
quietly replace criswmi=criswmi+crmip4 if crmip4~=.
quietly replace criswmi=criswmi+crmip5 if crmip5~=.
quietly replace criswmi=criswmi+crmip6 if crmip6~=.
quietly replace criswmi=criswmi+crmip7 if crmip7~=.
quietly replace criswmi=criswmi+crmip8 if crmip8~=.
quietly replace criswmi=criswmi+crmip9 if crmip9~=.
quietly replace criswmi=criswmi+crmip10 if crmip10~=.
quietly replace criswmi=criswmi+crmip11 if crmip11~=.
quietly replace criswmi=criswmi+crmip12 if crmip12~=.
quietly replace criswmi=criswmi+crmip13 if crmip13~=.
quietly replace criswmi=criswmi+crmip14 if crmip14~=.
quietly replace criswmi=criswmi+crmip15 if crmip15~=.
quietly replace criswmi=criswmi+crmip16 if crmip16~=.
quietly replace criswmi=criswmi+crmip17 if crmip17~=.
quietly replace criswmi=criswmi+crmip18 if crmip18~=.
quietly replace criswmi=criswmi+crmip19 if crmip19~=.
quietly replace criswmi=criswmi+crmip20 if crmip20~=.
quietly replace criswmi=criswmi+crmip21 if crmip21~=.

drop crmim1-crmim21
drop crmip1-crmip21
*
* The variable is p, the averaging is done via method i
*
quietly g crpim1=1-(normprob(wpi[_n-1])-normprob(wpi)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g crpim2=1-(normprob(wpi[_n-2])-normprob(wpi)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g crpim3=1-(normprob(wpi[_n-3])-normprob(wpi)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g crpim4=1-(normprob(wpi[_n-4])-normprob(wpi)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g crpim5=1-(normprob(wpi[_n-5])-normprob(wpi)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g crpim6=1-(normprob(wpi[_n-6])-normprob(wpi)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g crpim7=1-(normprob(wpi[_n-7])-normprob(wpi)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g crpim8=1-(normprob(wpi[_n-8])-normprob(wpi)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g crpim9=1-(normprob(wpi[_n-9])-normprob(wpi)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g crpim10=1-(normprob(wpi[_n-10])-normprob(wpi)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g crpim11=1-(normprob(wpi[_n-11])-normprob(wpi)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g crpim12=1-(normprob(wpi[_n-12])-normprob(wpi)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g crpim13=1-(normprob(wpi[_n-13])-normprob(wpi)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g crpim14=1-(normprob(wpi[_n-14])-normprob(wpi)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g crpim15=1-(normprob(wpi[_n-15])-normprob(wpi)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g crpim16=1-(normprob(wpi[_n-16])-normprob(wpi)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g crpim17=1-(normprob(wpi[_n-17])-normprob(wpi)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g crpim18=1-(normprob(wpi[_n-18])-normprob(wpi)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g crpim19=1-(normprob(wpi[_n-19])-normprob(wpi)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g crpim20=1-(normprob(wpi[_n-20])-normprob(wpi)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g crpim21=1-(normprob(wpi[_n-21])-normprob(wpi)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g crpip1=1-(normprob(wpi[_n+1])-normprob(wpi)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g crpip2=1-(normprob(wpi[_n+2])-normprob(wpi)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g crpip3=1-(normprob(wpi[_n+3])-normprob(wpi)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g crpip4=1-(normprob(wpi[_n+4])-normprob(wpi)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g crpip5=1-(normprob(wpi[_n+5])-normprob(wpi)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g crpip6=1-(normprob(wpi[_n+6])-normprob(wpi)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g crpip7=1-(normprob(wpi[_n+7])-normprob(wpi)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g crpip8=1-(normprob(wpi[_n+8])-normprob(wpi)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g crpip9=1-(normprob(wpi[_n+9])-normprob(wpi)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g crpip10=1-(normprob(wpi[_n+10])-normprob(wpi)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g crpip11=1-(normprob(wpi[_n+11])-normprob(wpi)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g crpip12=1-(normprob(wpi[_n+12])-normprob(wpi)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g crpip13=1-(normprob(wpi[_n+13])-normprob(wpi)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g crpip14=1-(normprob(wpi[_n+14])-normprob(wpi)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g crpip15=1-(normprob(wpi[_n+15])-normprob(wpi)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g crpip16=1-(normprob(wpi[_n+16])-normprob(wpi)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g crpip17=1-(normprob(wpi[_n+17])-normprob(wpi)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g crpip18=1-(normprob(wpi[_n+18])-normprob(wpi)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g crpip19=1-(normprob(wpi[_n+19])-normprob(wpi)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g crpip20=1-(normprob(wpi[_n+20])-normprob(wpi)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g crpip21=1-(normprob(wpi[_n+21])-normprob(wpi)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswpi=0

quietly replace criswpi=criswpi+crpim1 if crpim1~=.
quietly replace criswpi=criswpi+crpim2 if crpim2~=.
quietly replace criswpi=criswpi+crpim3 if crpim3~=.
quietly replace criswpi=criswpi+crpim4 if crpim4~=.
quietly replace criswpi=criswpi+crpim5 if crpim5~=.
quietly replace criswpi=criswpi+crpim6 if crpim6~=.
quietly replace criswpi=criswpi+crpim7 if crpim7~=.
quietly replace criswpi=criswpi+crpim8 if crpim8~=.
quietly replace criswpi=criswpi+crpim9 if crpim9~=.
quietly replace criswpi=criswpi+crpim10 if crpim10~=.
quietly replace criswpi=criswpi+crpim11 if crpim11~=.
quietly replace criswpi=criswpi+crpim12 if crpim12~=.
quietly replace criswpi=criswpi+crpim13 if crpim13~=.
quietly replace criswpi=criswpi+crpim14 if crpim14~=.
quietly replace criswpi=criswpi+crpim15 if crpim15~=.
quietly replace criswpi=criswpi+crpim16 if crpim16~=.
quietly replace criswpi=criswpi+crpim17 if crpim17~=.
quietly replace criswpi=criswpi+crpim18 if crpim18~=.
quietly replace criswpi=criswpi+crpim19 if crpim19~=.
quietly replace criswpi=criswpi+crpim20 if crpim20~=.
quietly replace criswpi=criswpi+crpim21 if crpim21~=.
quietly replace criswpi=criswpi+crpip1 if crpip1~=.
quietly replace criswpi=criswpi+crpip2 if crpip2~=.
quietly replace criswpi=criswpi+crpip3 if crpip3~=.
quietly replace criswpi=criswpi+crpip4 if crpip4~=.
quietly replace criswpi=criswpi+crpip5 if crpip5~=.
quietly replace criswpi=criswpi+crpip6 if crpip6~=.
quietly replace criswpi=criswpi+crpip7 if crpip7~=.
quietly replace criswpi=criswpi+crpip8 if crpip8~=.
quietly replace criswpi=criswpi+crpip9 if crpip9~=.
quietly replace criswpi=criswpi+crpip10 if crpip10~=.
quietly replace criswpi=criswpi+crpip11 if crpip11~=.
quietly replace criswpi=criswpi+crpip12 if crpip12~=.
quietly replace criswpi=criswpi+crpip13 if crpip13~=.
quietly replace criswpi=criswpi+crpip14 if crpip14~=.
quietly replace criswpi=criswpi+crpip15 if crpip15~=.
quietly replace criswpi=criswpi+crpip16 if crpip16~=.
quietly replace criswpi=criswpi+crpip17 if crpip17~=.
quietly replace criswpi=criswpi+crpip18 if crpip18~=.
quietly replace criswpi=criswpi+crpip19 if crpip19~=.
quietly replace criswpi=criswpi+crpip20 if crpip20~=.
quietly replace criswpi=criswpi+crpip21 if crpip21~=.

drop crpim1-crpim21
drop crpip1-crpip21
*
* The variable is y, the averaging is done via method i
*
quietly g cryim1=1-(normprob(wyi[_n-1])-normprob(wyi)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g cryim2=1-(normprob(wyi[_n-2])-normprob(wyi)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g cryim3=1-(normprob(wyi[_n-3])-normprob(wyi)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g cryim4=1-(normprob(wyi[_n-4])-normprob(wyi)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g cryim5=1-(normprob(wyi[_n-5])-normprob(wyi)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g cryim6=1-(normprob(wyi[_n-6])-normprob(wyi)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g cryim7=1-(normprob(wyi[_n-7])-normprob(wyi)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g cryim8=1-(normprob(wyi[_n-8])-normprob(wyi)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g cryim9=1-(normprob(wyi[_n-9])-normprob(wyi)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g cryim10=1-(normprob(wyi[_n-10])-normprob(wyi)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g cryim11=1-(normprob(wyi[_n-11])-normprob(wyi)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g cryim12=1-(normprob(wyi[_n-12])-normprob(wyi)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g cryim13=1-(normprob(wyi[_n-13])-normprob(wyi)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g cryim14=1-(normprob(wyi[_n-14])-normprob(wyi)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g cryim15=1-(normprob(wyi[_n-15])-normprob(wyi)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g cryim16=1-(normprob(wyi[_n-16])-normprob(wyi)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g cryim17=1-(normprob(wyi[_n-17])-normprob(wyi)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g cryim18=1-(normprob(wyi[_n-18])-normprob(wyi)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g cryim19=1-(normprob(wyi[_n-19])-normprob(wyi)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g cryim20=1-(normprob(wyi[_n-20])-normprob(wyi)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g cryim21=1-(normprob(wyi[_n-21])-normprob(wyi)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g cryip1=1-(normprob(wyi[_n+1])-normprob(wyi)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g cryip2=1-(normprob(wyi[_n+2])-normprob(wyi)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g cryip3=1-(normprob(wyi[_n+3])-normprob(wyi)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g cryip4=1-(normprob(wyi[_n+4])-normprob(wyi)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g cryip5=1-(normprob(wyi[_n+5])-normprob(wyi)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g cryip6=1-(normprob(wyi[_n+6])-normprob(wyi)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g cryip7=1-(normprob(wyi[_n+7])-normprob(wyi)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g cryip8=1-(normprob(wyi[_n+8])-normprob(wyi)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g cryip9=1-(normprob(wyi[_n+9])-normprob(wyi)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g cryip10=1-(normprob(wyi[_n+10])-normprob(wyi)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g cryip11=1-(normprob(wyi[_n+11])-normprob(wyi)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g cryip12=1-(normprob(wyi[_n+12])-normprob(wyi)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g cryip13=1-(normprob(wyi[_n+13])-normprob(wyi)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g cryip14=1-(normprob(wyi[_n+14])-normprob(wyi)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g cryip15=1-(normprob(wyi[_n+15])-normprob(wyi)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g cryip16=1-(normprob(wyi[_n+16])-normprob(wyi)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g cryip17=1-(normprob(wyi[_n+17])-normprob(wyi)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g cryip18=1-(normprob(wyi[_n+18])-normprob(wyi)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g cryip19=1-(normprob(wyi[_n+19])-normprob(wyi)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g cryip20=1-(normprob(wyi[_n+20])-normprob(wyi)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g cryip21=1-(normprob(wyi[_n+21])-normprob(wyi)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswyi=0

quietly replace criswyi=criswyi+cryim1 if cryim1~=.
quietly replace criswyi=criswyi+cryim2 if cryim2~=.
quietly replace criswyi=criswyi+cryim3 if cryim3~=.
quietly replace criswyi=criswyi+cryim4 if cryim4~=.
quietly replace criswyi=criswyi+cryim5 if cryim5~=.
quietly replace criswyi=criswyi+cryim6 if cryim6~=.
quietly replace criswyi=criswyi+cryim7 if cryim7~=.
quietly replace criswyi=criswyi+cryim8 if cryim8~=.
quietly replace criswyi=criswyi+cryim9 if cryim9~=.
quietly replace criswyi=criswyi+cryim10 if cryim10~=.
quietly replace criswyi=criswyi+cryim11 if cryim11~=.
quietly replace criswyi=criswyi+cryim12 if cryim12~=.
quietly replace criswyi=criswyi+cryim13 if cryim13~=.
quietly replace criswyi=criswyi+cryim14 if cryim14~=.
quietly replace criswyi=criswyi+cryim15 if cryim15~=.
quietly replace criswyi=criswyi+cryim16 if cryim16~=.
quietly replace criswyi=criswyi+cryim17 if cryim17~=.
quietly replace criswyi=criswyi+cryim18 if cryim18~=.
quietly replace criswyi=criswyi+cryim19 if cryim19~=.
quietly replace criswyi=criswyi+cryim20 if cryim20~=.
quietly replace criswyi=criswyi+cryim21 if cryim21~=.
quietly replace criswyi=criswyi+cryip1 if cryip1~=.
quietly replace criswyi=criswyi+cryip2 if cryip2~=.
quietly replace criswyi=criswyi+cryip3 if cryip3~=.
quietly replace criswyi=criswyi+cryip4 if cryip4~=.
quietly replace criswyi=criswyi+cryip5 if cryip5~=.
quietly replace criswyi=criswyi+cryip6 if cryip6~=.
quietly replace criswyi=criswyi+cryip7 if cryip7~=.
quietly replace criswyi=criswyi+cryip8 if cryip8~=.
quietly replace criswyi=criswyi+cryip9 if cryip9~=.
quietly replace criswyi=criswyi+cryip10 if cryip10~=.
quietly replace criswyi=criswyi+cryip11 if cryip11~=.
quietly replace criswyi=criswyi+cryip12 if cryip12~=.
quietly replace criswyi=criswyi+cryip13 if cryip13~=.
quietly replace criswyi=criswyi+cryip14 if cryip14~=.
quietly replace criswyi=criswyi+cryip15 if cryip15~=.
quietly replace criswyi=criswyi+cryip16 if cryip16~=.
quietly replace criswyi=criswyi+cryip17 if cryip17~=.
quietly replace criswyi=criswyi+cryip18 if cryip18~=.
quietly replace criswyi=criswyi+cryip19 if cryip19~=.
quietly replace criswyi=criswyi+cryip20 if cryip20~=.
quietly replace criswyi=criswyi+cryip21 if cryip21~=.

drop cryim1-cryim21
drop cryip1-cryip21
*
* The variable is u, the averaging is done via method i
*
quietly g cruim1=1-(normprob(wui[_n-1])-normprob(wui)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g cruim2=1-(normprob(wui[_n-2])-normprob(wui)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g cruim3=1-(normprob(wui[_n-3])-normprob(wui)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g cruim4=1-(normprob(wui[_n-4])-normprob(wui)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g cruim5=1-(normprob(wui[_n-5])-normprob(wui)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g cruim6=1-(normprob(wui[_n-6])-normprob(wui)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g cruim7=1-(normprob(wui[_n-7])-normprob(wui)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g cruim8=1-(normprob(wui[_n-8])-normprob(wui)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g cruim9=1-(normprob(wui[_n-9])-normprob(wui)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g cruim10=1-(normprob(wui[_n-10])-normprob(wui)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g cruim11=1-(normprob(wui[_n-11])-normprob(wui)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g cruim12=1-(normprob(wui[_n-12])-normprob(wui)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g cruim13=1-(normprob(wui[_n-13])-normprob(wui)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g cruim14=1-(normprob(wui[_n-14])-normprob(wui)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g cruim15=1-(normprob(wui[_n-15])-normprob(wui)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g cruim16=1-(normprob(wui[_n-16])-normprob(wui)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g cruim17=1-(normprob(wui[_n-17])-normprob(wui)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g cruim18=1-(normprob(wui[_n-18])-normprob(wui)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g cruim19=1-(normprob(wui[_n-19])-normprob(wui)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g cruim20=1-(normprob(wui[_n-20])-normprob(wui)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g cruim21=1-(normprob(wui[_n-21])-normprob(wui)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g cruip1=1-(normprob(wui[_n+1])-normprob(wui)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g cruip2=1-(normprob(wui[_n+2])-normprob(wui)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g cruip3=1-(normprob(wui[_n+3])-normprob(wui)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g cruip4=1-(normprob(wui[_n+4])-normprob(wui)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g cruip5=1-(normprob(wui[_n+5])-normprob(wui)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g cruip6=1-(normprob(wui[_n+6])-normprob(wui)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g cruip7=1-(normprob(wui[_n+7])-normprob(wui)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g cruip8=1-(normprob(wui[_n+8])-normprob(wui)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g cruip9=1-(normprob(wui[_n+9])-normprob(wui)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g cruip10=1-(normprob(wui[_n+10])-normprob(wui)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g cruip11=1-(normprob(wui[_n+11])-normprob(wui)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g cruip12=1-(normprob(wui[_n+12])-normprob(wui)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g cruip13=1-(normprob(wui[_n+13])-normprob(wui)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g cruip14=1-(normprob(wui[_n+14])-normprob(wui)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g cruip15=1-(normprob(wui[_n+15])-normprob(wui)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g cruip16=1-(normprob(wui[_n+16])-normprob(wui)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g cruip17=1-(normprob(wui[_n+17])-normprob(wui)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g cruip18=1-(normprob(wui[_n+18])-normprob(wui)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g cruip19=1-(normprob(wui[_n+19])-normprob(wui)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g cruip20=1-(normprob(wui[_n+20])-normprob(wui)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g cruip21=1-(normprob(wui[_n+21])-normprob(wui)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswui=0

quietly replace criswui=criswui+cruim1 if cruim1~=.
quietly replace criswui=criswui+cruim2 if cruim2~=.
quietly replace criswui=criswui+cruim3 if cruim3~=.
quietly replace criswui=criswui+cruim4 if cruim4~=.
quietly replace criswui=criswui+cruim5 if cruim5~=.
quietly replace criswui=criswui+cruim6 if cruim6~=.
quietly replace criswui=criswui+cruim7 if cruim7~=.
quietly replace criswui=criswui+cruim8 if cruim8~=.
quietly replace criswui=criswui+cruim9 if cruim9~=.
quietly replace criswui=criswui+cruim10 if cruim10~=.
quietly replace criswui=criswui+cruim11 if cruim11~=.
quietly replace criswui=criswui+cruim12 if cruim12~=.
quietly replace criswui=criswui+cruim13 if cruim13~=.
quietly replace criswui=criswui+cruim14 if cruim14~=.
quietly replace criswui=criswui+cruim15 if cruim15~=.
quietly replace criswui=criswui+cruim16 if cruim16~=.
quietly replace criswui=criswui+cruim17 if cruim17~=.
quietly replace criswui=criswui+cruim18 if cruim18~=.
quietly replace criswui=criswui+cruim19 if cruim19~=.
quietly replace criswui=criswui+cruim20 if cruim20~=.
quietly replace criswui=criswui+cruim21 if cruim21~=.
quietly replace criswui=criswui+cruip1 if cruip1~=.
quietly replace criswui=criswui+cruip2 if cruip2~=.
quietly replace criswui=criswui+cruip3 if cruip3~=.
quietly replace criswui=criswui+cruip4 if cruip4~=.
quietly replace criswui=criswui+cruip5 if cruip5~=.
quietly replace criswui=criswui+cruip6 if cruip6~=.
quietly replace criswui=criswui+cruip7 if cruip7~=.
quietly replace criswui=criswui+cruip8 if cruip8~=.
quietly replace criswui=criswui+cruip9 if cruip9~=.
quietly replace criswui=criswui+cruip10 if cruip10~=.
quietly replace criswui=criswui+cruip11 if cruip11~=.
quietly replace criswui=criswui+cruip12 if cruip12~=.
quietly replace criswui=criswui+cruip13 if cruip13~=.
quietly replace criswui=criswui+cruip14 if cruip14~=.
quietly replace criswui=criswui+cruip15 if cruip15~=.
quietly replace criswui=criswui+cruip16 if cruip16~=.
quietly replace criswui=criswui+cruip17 if cruip17~=.
quietly replace criswui=criswui+cruip18 if cruip18~=.
quietly replace criswui=criswui+cruip19 if cruip19~=.
quietly replace criswui=criswui+cruip20 if cruip20~=.
quietly replace criswui=criswui+cruip21 if cruip21~=.

drop cruim1-cruim21
drop cruip1-cruip21
*
* The variable is t, the averaging is done via method i
*
quietly g crtim1=1-(normprob(wti[_n-1])-normprob(wti)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g crtim2=1-(normprob(wti[_n-2])-normprob(wti)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g crtim3=1-(normprob(wti[_n-3])-normprob(wti)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g crtim4=1-(normprob(wti[_n-4])-normprob(wti)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g crtim5=1-(normprob(wti[_n-5])-normprob(wti)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g crtim6=1-(normprob(wti[_n-6])-normprob(wti)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g crtim7=1-(normprob(wti[_n-7])-normprob(wti)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g crtim8=1-(normprob(wti[_n-8])-normprob(wti)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g crtim9=1-(normprob(wti[_n-9])-normprob(wti)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g crtim10=1-(normprob(wti[_n-10])-normprob(wti)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g crtim11=1-(normprob(wti[_n-11])-normprob(wti)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g crtim12=1-(normprob(wti[_n-12])-normprob(wti)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g crtim13=1-(normprob(wti[_n-13])-normprob(wti)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g crtim14=1-(normprob(wti[_n-14])-normprob(wti)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g crtim15=1-(normprob(wti[_n-15])-normprob(wti)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g crtim16=1-(normprob(wti[_n-16])-normprob(wti)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g crtim17=1-(normprob(wti[_n-17])-normprob(wti)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g crtim18=1-(normprob(wti[_n-18])-normprob(wti)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g crtim19=1-(normprob(wti[_n-19])-normprob(wti)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g crtim20=1-(normprob(wti[_n-20])-normprob(wti)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g crtim21=1-(normprob(wti[_n-21])-normprob(wti)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g crtip1=1-(normprob(wti[_n+1])-normprob(wti)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g crtip2=1-(normprob(wti[_n+2])-normprob(wti)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g crtip3=1-(normprob(wti[_n+3])-normprob(wti)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g crtip4=1-(normprob(wti[_n+4])-normprob(wti)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g crtip5=1-(normprob(wti[_n+5])-normprob(wti)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g crtip6=1-(normprob(wti[_n+6])-normprob(wti)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g crtip7=1-(normprob(wti[_n+7])-normprob(wti)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g crtip8=1-(normprob(wti[_n+8])-normprob(wti)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g crtip9=1-(normprob(wti[_n+9])-normprob(wti)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g crtip10=1-(normprob(wti[_n+10])-normprob(wti)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g crtip11=1-(normprob(wti[_n+11])-normprob(wti)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g crtip12=1-(normprob(wti[_n+12])-normprob(wti)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g crtip13=1-(normprob(wti[_n+13])-normprob(wti)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g crtip14=1-(normprob(wti[_n+14])-normprob(wti)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g crtip15=1-(normprob(wti[_n+15])-normprob(wti)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g crtip16=1-(normprob(wti[_n+16])-normprob(wti)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g crtip17=1-(normprob(wti[_n+17])-normprob(wti)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g crtip18=1-(normprob(wti[_n+18])-normprob(wti)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g crtip19=1-(normprob(wti[_n+19])-normprob(wti)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g crtip20=1-(normprob(wti[_n+20])-normprob(wti)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g crtip21=1-(normprob(wti[_n+21])-normprob(wti)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswti=0

quietly replace criswti=criswti+crtim1 if crtim1~=.
quietly replace criswti=criswti+crtim2 if crtim2~=.
quietly replace criswti=criswti+crtim3 if crtim3~=.
quietly replace criswti=criswti+crtim4 if crtim4~=.
quietly replace criswti=criswti+crtim5 if crtim5~=.
quietly replace criswti=criswti+crtim6 if crtim6~=.
quietly replace criswti=criswti+crtim7 if crtim7~=.
quietly replace criswti=criswti+crtim8 if crtim8~=.
quietly replace criswti=criswti+crtim9 if crtim9~=.
quietly replace criswti=criswti+crtim10 if crtim10~=.
quietly replace criswti=criswti+crtim11 if crtim11~=.
quietly replace criswti=criswti+crtim12 if crtim12~=.
quietly replace criswti=criswti+crtim13 if crtim13~=.
quietly replace criswti=criswti+crtim14 if crtim14~=.
quietly replace criswti=criswti+crtim15 if crtim15~=.
quietly replace criswti=criswti+crtim16 if crtim16~=.
quietly replace criswti=criswti+crtim17 if crtim17~=.
quietly replace criswti=criswti+crtim18 if crtim18~=.
quietly replace criswti=criswti+crtim19 if crtim19~=.
quietly replace criswti=criswti+crtim20 if crtim20~=.
quietly replace criswti=criswti+crtim21 if crtim21~=.
quietly replace criswti=criswti+crtip1 if crtip1~=.
quietly replace criswti=criswti+crtip2 if crtip2~=.
quietly replace criswti=criswti+crtip3 if crtip3~=.
quietly replace criswti=criswti+crtip4 if crtip4~=.
quietly replace criswti=criswti+crtip5 if crtip5~=.
quietly replace criswti=criswti+crtip6 if crtip6~=.
quietly replace criswti=criswti+crtip7 if crtip7~=.
quietly replace criswti=criswti+crtip8 if crtip8~=.
quietly replace criswti=criswti+crtip9 if crtip9~=.
quietly replace criswti=criswti+crtip10 if crtip10~=.
quietly replace criswti=criswti+crtip11 if crtip11~=.
quietly replace criswti=criswti+crtip12 if crtip12~=.
quietly replace criswti=criswti+crtip13 if crtip13~=.
quietly replace criswti=criswti+crtip14 if crtip14~=.
quietly replace criswti=criswti+crtip15 if crtip15~=.
quietly replace criswti=criswti+crtip16 if crtip16~=.
quietly replace criswti=criswti+crtip17 if crtip17~=.
quietly replace criswti=criswti+crtip18 if crtip18~=.
quietly replace criswti=criswti+crtip19 if crtip19~=.
quietly replace criswti=criswti+crtip20 if crtip20~=.
quietly replace criswti=criswti+crtip21 if crtip21~=.

drop crtim1-crtim21
drop crtip1-crtip21
*
* The variable is b, the averaging is done via method i
*
quietly g crbim1=1-(normprob(wbi[_n-1])-normprob(wbi)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g crbim2=1-(normprob(wbi[_n-2])-normprob(wbi)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g crbim3=1-(normprob(wbi[_n-3])-normprob(wbi)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g crbim4=1-(normprob(wbi[_n-4])-normprob(wbi)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g crbim5=1-(normprob(wbi[_n-5])-normprob(wbi)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g crbim6=1-(normprob(wbi[_n-6])-normprob(wbi)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g crbim7=1-(normprob(wbi[_n-7])-normprob(wbi)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g crbim8=1-(normprob(wbi[_n-8])-normprob(wbi)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g crbim9=1-(normprob(wbi[_n-9])-normprob(wbi)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g crbim10=1-(normprob(wbi[_n-10])-normprob(wbi)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g crbim11=1-(normprob(wbi[_n-11])-normprob(wbi)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g crbim12=1-(normprob(wbi[_n-12])-normprob(wbi)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g crbim13=1-(normprob(wbi[_n-13])-normprob(wbi)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g crbim14=1-(normprob(wbi[_n-14])-normprob(wbi)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g crbim15=1-(normprob(wbi[_n-15])-normprob(wbi)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g crbim16=1-(normprob(wbi[_n-16])-normprob(wbi)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g crbim17=1-(normprob(wbi[_n-17])-normprob(wbi)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g crbim18=1-(normprob(wbi[_n-18])-normprob(wbi)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g crbim19=1-(normprob(wbi[_n-19])-normprob(wbi)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g crbim20=1-(normprob(wbi[_n-20])-normprob(wbi)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g crbim21=1-(normprob(wbi[_n-21])-normprob(wbi)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g crbip1=1-(normprob(wbi[_n+1])-normprob(wbi)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g crbip2=1-(normprob(wbi[_n+2])-normprob(wbi)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g crbip3=1-(normprob(wbi[_n+3])-normprob(wbi)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g crbip4=1-(normprob(wbi[_n+4])-normprob(wbi)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g crbip5=1-(normprob(wbi[_n+5])-normprob(wbi)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g crbip6=1-(normprob(wbi[_n+6])-normprob(wbi)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g crbip7=1-(normprob(wbi[_n+7])-normprob(wbi)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g crbip8=1-(normprob(wbi[_n+8])-normprob(wbi)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g crbip9=1-(normprob(wbi[_n+9])-normprob(wbi)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g crbip10=1-(normprob(wbi[_n+10])-normprob(wbi)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g crbip11=1-(normprob(wbi[_n+11])-normprob(wbi)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g crbip12=1-(normprob(wbi[_n+12])-normprob(wbi)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g crbip13=1-(normprob(wbi[_n+13])-normprob(wbi)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g crbip14=1-(normprob(wbi[_n+14])-normprob(wbi)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g crbip15=1-(normprob(wbi[_n+15])-normprob(wbi)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g crbip16=1-(normprob(wbi[_n+16])-normprob(wbi)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g crbip17=1-(normprob(wbi[_n+17])-normprob(wbi)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g crbip18=1-(normprob(wbi[_n+18])-normprob(wbi)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g crbip19=1-(normprob(wbi[_n+19])-normprob(wbi)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g crbip20=1-(normprob(wbi[_n+20])-normprob(wbi)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g crbip21=1-(normprob(wbi[_n+21])-normprob(wbi)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswbi=0

quietly replace criswbi=criswbi+crbim1 if crbim1~=.
quietly replace criswbi=criswbi+crbim2 if crbim2~=.
quietly replace criswbi=criswbi+crbim3 if crbim3~=.
quietly replace criswbi=criswbi+crbim4 if crbim4~=.
quietly replace criswbi=criswbi+crbim5 if crbim5~=.
quietly replace criswbi=criswbi+crbim6 if crbim6~=.
quietly replace criswbi=criswbi+crbim7 if crbim7~=.
quietly replace criswbi=criswbi+crbim8 if crbim8~=.
quietly replace criswbi=criswbi+crbim9 if crbim9~=.
quietly replace criswbi=criswbi+crbim10 if crbim10~=.
quietly replace criswbi=criswbi+crbim11 if crbim11~=.
quietly replace criswbi=criswbi+crbim12 if crbim12~=.
quietly replace criswbi=criswbi+crbim13 if crbim13~=.
quietly replace criswbi=criswbi+crbim14 if crbim14~=.
quietly replace criswbi=criswbi+crbim15 if crbim15~=.
quietly replace criswbi=criswbi+crbim16 if crbim16~=.
quietly replace criswbi=criswbi+crbim17 if crbim17~=.
quietly replace criswbi=criswbi+crbim18 if crbim18~=.
quietly replace criswbi=criswbi+crbim19 if crbim19~=.
quietly replace criswbi=criswbi+crbim20 if crbim20~=.
quietly replace criswbi=criswbi+crbim21 if crbim21~=.
quietly replace criswbi=criswbi+crbip1 if crbip1~=.
quietly replace criswbi=criswbi+crbip2 if crbip2~=.
quietly replace criswbi=criswbi+crbip3 if crbip3~=.
quietly replace criswbi=criswbi+crbip4 if crbip4~=.
quietly replace criswbi=criswbi+crbip5 if crbip5~=.
quietly replace criswbi=criswbi+crbip6 if crbip6~=.
quietly replace criswbi=criswbi+crbip7 if crbip7~=.
quietly replace criswbi=criswbi+crbip8 if crbip8~=.
quietly replace criswbi=criswbi+crbip9 if crbip9~=.
quietly replace criswbi=criswbi+crbip10 if crbip10~=.
quietly replace criswbi=criswbi+crbip11 if crbip11~=.
quietly replace criswbi=criswbi+crbip12 if crbip12~=.
quietly replace criswbi=criswbi+crbip13 if crbip13~=.
quietly replace criswbi=criswbi+crbip14 if crbip14~=.
quietly replace criswbi=criswbi+crbip15 if crbip15~=.
quietly replace criswbi=criswbi+crbip16 if crbip16~=.
quietly replace criswbi=criswbi+crbip17 if crbip17~=.
quietly replace criswbi=criswbi+crbip18 if crbip18~=.
quietly replace criswbi=criswbi+crbip19 if crbip19~=.
quietly replace criswbi=criswbi+crbip20 if crbip20~=.
quietly replace criswbi=criswbi+crbip21 if crbip21~=.

drop crbim1-crbim21
drop crbip1-crbip21
*
* The variable is c, the averaging is done via method t
*
quietly g crctm1=1-(normprob(wct[_n-1])-normprob(wct)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g crctm2=1-(normprob(wct[_n-2])-normprob(wct)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g crctm3=1-(normprob(wct[_n-3])-normprob(wct)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g crctm4=1-(normprob(wct[_n-4])-normprob(wct)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g crctm5=1-(normprob(wct[_n-5])-normprob(wct)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g crctm6=1-(normprob(wct[_n-6])-normprob(wct)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g crctm7=1-(normprob(wct[_n-7])-normprob(wct)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g crctm8=1-(normprob(wct[_n-8])-normprob(wct)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g crctm9=1-(normprob(wct[_n-9])-normprob(wct)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g crctm10=1-(normprob(wct[_n-10])-normprob(wct)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g crctm11=1-(normprob(wct[_n-11])-normprob(wct)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g crctm12=1-(normprob(wct[_n-12])-normprob(wct)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g crctm13=1-(normprob(wct[_n-13])-normprob(wct)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g crctm14=1-(normprob(wct[_n-14])-normprob(wct)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g crctm15=1-(normprob(wct[_n-15])-normprob(wct)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g crctm16=1-(normprob(wct[_n-16])-normprob(wct)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g crctm17=1-(normprob(wct[_n-17])-normprob(wct)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g crctm18=1-(normprob(wct[_n-18])-normprob(wct)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g crctm19=1-(normprob(wct[_n-19])-normprob(wct)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g crctm20=1-(normprob(wct[_n-20])-normprob(wct)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g crctm21=1-(normprob(wct[_n-21])-normprob(wct)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g crctp1=1-(normprob(wct[_n+1])-normprob(wct)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g crctp2=1-(normprob(wct[_n+2])-normprob(wct)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g crctp3=1-(normprob(wct[_n+3])-normprob(wct)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g crctp4=1-(normprob(wct[_n+4])-normprob(wct)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g crctp5=1-(normprob(wct[_n+5])-normprob(wct)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g crctp6=1-(normprob(wct[_n+6])-normprob(wct)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g crctp7=1-(normprob(wct[_n+7])-normprob(wct)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g crctp8=1-(normprob(wct[_n+8])-normprob(wct)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g crctp9=1-(normprob(wct[_n+9])-normprob(wct)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g crctp10=1-(normprob(wct[_n+10])-normprob(wct)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g crctp11=1-(normprob(wct[_n+11])-normprob(wct)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g crctp12=1-(normprob(wct[_n+12])-normprob(wct)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g crctp13=1-(normprob(wct[_n+13])-normprob(wct)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g crctp14=1-(normprob(wct[_n+14])-normprob(wct)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g crctp15=1-(normprob(wct[_n+15])-normprob(wct)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g crctp16=1-(normprob(wct[_n+16])-normprob(wct)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g crctp17=1-(normprob(wct[_n+17])-normprob(wct)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g crctp18=1-(normprob(wct[_n+18])-normprob(wct)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g crctp19=1-(normprob(wct[_n+19])-normprob(wct)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g crctp20=1-(normprob(wct[_n+20])-normprob(wct)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g crctp21=1-(normprob(wct[_n+21])-normprob(wct)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswct=0

quietly replace criswct=criswct+crctm1 if crctm1~=.
quietly replace criswct=criswct+crctm2 if crctm2~=.
quietly replace criswct=criswct+crctm3 if crctm3~=.
quietly replace criswct=criswct+crctm4 if crctm4~=.
quietly replace criswct=criswct+crctm5 if crctm5~=.
quietly replace criswct=criswct+crctm6 if crctm6~=.
quietly replace criswct=criswct+crctm7 if crctm7~=.
quietly replace criswct=criswct+crctm8 if crctm8~=.
quietly replace criswct=criswct+crctm9 if crctm9~=.
quietly replace criswct=criswct+crctm10 if crctm10~=.
quietly replace criswct=criswct+crctm11 if crctm11~=.
quietly replace criswct=criswct+crctm12 if crctm12~=.
quietly replace criswct=criswct+crctm13 if crctm13~=.
quietly replace criswct=criswct+crctm14 if crctm14~=.
quietly replace criswct=criswct+crctm15 if crctm15~=.
quietly replace criswct=criswct+crctm16 if crctm16~=.
quietly replace criswct=criswct+crctm17 if crctm17~=.
quietly replace criswct=criswct+crctm18 if crctm18~=.
quietly replace criswct=criswct+crctm19 if crctm19~=.
quietly replace criswct=criswct+crctm20 if crctm20~=.
quietly replace criswct=criswct+crctm21 if crctm21~=.
quietly replace criswct=criswct+crctp1 if crctp1~=.
quietly replace criswct=criswct+crctp2 if crctp2~=.
quietly replace criswct=criswct+crctp3 if crctp3~=.
quietly replace criswct=criswct+crctp4 if crctp4~=.
quietly replace criswct=criswct+crctp5 if crctp5~=.
quietly replace criswct=criswct+crctp6 if crctp6~=.
quietly replace criswct=criswct+crctp7 if crctp7~=.
quietly replace criswct=criswct+crctp8 if crctp8~=.
quietly replace criswct=criswct+crctp9 if crctp9~=.
quietly replace criswct=criswct+crctp10 if crctp10~=.
quietly replace criswct=criswct+crctp11 if crctp11~=.
quietly replace criswct=criswct+crctp12 if crctp12~=.
quietly replace criswct=criswct+crctp13 if crctp13~=.
quietly replace criswct=criswct+crctp14 if crctp14~=.
quietly replace criswct=criswct+crctp15 if crctp15~=.
quietly replace criswct=criswct+crctp16 if crctp16~=.
quietly replace criswct=criswct+crctp17 if crctp17~=.
quietly replace criswct=criswct+crctp18 if crctp18~=.
quietly replace criswct=criswct+crctp19 if crctp19~=.
quietly replace criswct=criswct+crctp20 if crctp20~=.
quietly replace criswct=criswct+crctp21 if crctp21~=.

drop crctm1-crctm21
drop crctp1-crctp21
*
* The variable is m, the averaging is done via method t
*
quietly g crmtm1=1-(normprob(wmt[_n-1])-normprob(wmt)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g crmtm2=1-(normprob(wmt[_n-2])-normprob(wmt)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g crmtm3=1-(normprob(wmt[_n-3])-normprob(wmt)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g crmtm4=1-(normprob(wmt[_n-4])-normprob(wmt)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g crmtm5=1-(normprob(wmt[_n-5])-normprob(wmt)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g crmtm6=1-(normprob(wmt[_n-6])-normprob(wmt)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g crmtm7=1-(normprob(wmt[_n-7])-normprob(wmt)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g crmtm8=1-(normprob(wmt[_n-8])-normprob(wmt)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g crmtm9=1-(normprob(wmt[_n-9])-normprob(wmt)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g crmtm10=1-(normprob(wmt[_n-10])-normprob(wmt)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g crmtm11=1-(normprob(wmt[_n-11])-normprob(wmt)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g crmtm12=1-(normprob(wmt[_n-12])-normprob(wmt)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g crmtm13=1-(normprob(wmt[_n-13])-normprob(wmt)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g crmtm14=1-(normprob(wmt[_n-14])-normprob(wmt)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g crmtm15=1-(normprob(wmt[_n-15])-normprob(wmt)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g crmtm16=1-(normprob(wmt[_n-16])-normprob(wmt)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g crmtm17=1-(normprob(wmt[_n-17])-normprob(wmt)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g crmtm18=1-(normprob(wmt[_n-18])-normprob(wmt)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g crmtm19=1-(normprob(wmt[_n-19])-normprob(wmt)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g crmtm20=1-(normprob(wmt[_n-20])-normprob(wmt)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g crmtm21=1-(normprob(wmt[_n-21])-normprob(wmt)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g crmtp1=1-(normprob(wmt[_n+1])-normprob(wmt)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g crmtp2=1-(normprob(wmt[_n+2])-normprob(wmt)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g crmtp3=1-(normprob(wmt[_n+3])-normprob(wmt)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g crmtp4=1-(normprob(wmt[_n+4])-normprob(wmt)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g crmtp5=1-(normprob(wmt[_n+5])-normprob(wmt)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g crmtp6=1-(normprob(wmt[_n+6])-normprob(wmt)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g crmtp7=1-(normprob(wmt[_n+7])-normprob(wmt)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g crmtp8=1-(normprob(wmt[_n+8])-normprob(wmt)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g crmtp9=1-(normprob(wmt[_n+9])-normprob(wmt)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g crmtp10=1-(normprob(wmt[_n+10])-normprob(wmt)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g crmtp11=1-(normprob(wmt[_n+11])-normprob(wmt)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g crmtp12=1-(normprob(wmt[_n+12])-normprob(wmt)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g crmtp13=1-(normprob(wmt[_n+13])-normprob(wmt)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g crmtp14=1-(normprob(wmt[_n+14])-normprob(wmt)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g crmtp15=1-(normprob(wmt[_n+15])-normprob(wmt)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g crmtp16=1-(normprob(wmt[_n+16])-normprob(wmt)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g crmtp17=1-(normprob(wmt[_n+17])-normprob(wmt)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g crmtp18=1-(normprob(wmt[_n+18])-normprob(wmt)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g crmtp19=1-(normprob(wmt[_n+19])-normprob(wmt)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g crmtp20=1-(normprob(wmt[_n+20])-normprob(wmt)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g crmtp21=1-(normprob(wmt[_n+21])-normprob(wmt)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswmt=0

quietly replace criswmt=criswmt+crmtm1 if crmtm1~=.
quietly replace criswmt=criswmt+crmtm2 if crmtm2~=.
quietly replace criswmt=criswmt+crmtm3 if crmtm3~=.
quietly replace criswmt=criswmt+crmtm4 if crmtm4~=.
quietly replace criswmt=criswmt+crmtm5 if crmtm5~=.
quietly replace criswmt=criswmt+crmtm6 if crmtm6~=.
quietly replace criswmt=criswmt+crmtm7 if crmtm7~=.
quietly replace criswmt=criswmt+crmtm8 if crmtm8~=.
quietly replace criswmt=criswmt+crmtm9 if crmtm9~=.
quietly replace criswmt=criswmt+crmtm10 if crmtm10~=.
quietly replace criswmt=criswmt+crmtm11 if crmtm11~=.
quietly replace criswmt=criswmt+crmtm12 if crmtm12~=.
quietly replace criswmt=criswmt+crmtm13 if crmtm13~=.
quietly replace criswmt=criswmt+crmtm14 if crmtm14~=.
quietly replace criswmt=criswmt+crmtm15 if crmtm15~=.
quietly replace criswmt=criswmt+crmtm16 if crmtm16~=.
quietly replace criswmt=criswmt+crmtm17 if crmtm17~=.
quietly replace criswmt=criswmt+crmtm18 if crmtm18~=.
quietly replace criswmt=criswmt+crmtm19 if crmtm19~=.
quietly replace criswmt=criswmt+crmtm20 if crmtm20~=.
quietly replace criswmt=criswmt+crmtm21 if crmtm21~=.
quietly replace criswmt=criswmt+crmtp1 if crmtp1~=.
quietly replace criswmt=criswmt+crmtp2 if crmtp2~=.
quietly replace criswmt=criswmt+crmtp3 if crmtp3~=.
quietly replace criswmt=criswmt+crmtp4 if crmtp4~=.
quietly replace criswmt=criswmt+crmtp5 if crmtp5~=.
quietly replace criswmt=criswmt+crmtp6 if crmtp6~=.
quietly replace criswmt=criswmt+crmtp7 if crmtp7~=.
quietly replace criswmt=criswmt+crmtp8 if crmtp8~=.
quietly replace criswmt=criswmt+crmtp9 if crmtp9~=.
quietly replace criswmt=criswmt+crmtp10 if crmtp10~=.
quietly replace criswmt=criswmt+crmtp11 if crmtp11~=.
quietly replace criswmt=criswmt+crmtp12 if crmtp12~=.
quietly replace criswmt=criswmt+crmtp13 if crmtp13~=.
quietly replace criswmt=criswmt+crmtp14 if crmtp14~=.
quietly replace criswmt=criswmt+crmtp15 if crmtp15~=.
quietly replace criswmt=criswmt+crmtp16 if crmtp16~=.
quietly replace criswmt=criswmt+crmtp17 if crmtp17~=.
quietly replace criswmt=criswmt+crmtp18 if crmtp18~=.
quietly replace criswmt=criswmt+crmtp19 if crmtp19~=.
quietly replace criswmt=criswmt+crmtp20 if crmtp20~=.
quietly replace criswmt=criswmt+crmtp21 if crmtp21~=.

drop crmtm1-crmtm21
drop crmtp1-crmtp21
*
* The variable is p, the averaging is done via method t
*
quietly g crptm1=1-(normprob(wpt[_n-1])-normprob(wpt)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g crptm2=1-(normprob(wpt[_n-2])-normprob(wpt)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g crptm3=1-(normprob(wpt[_n-3])-normprob(wpt)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g crptm4=1-(normprob(wpt[_n-4])-normprob(wpt)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g crptm5=1-(normprob(wpt[_n-5])-normprob(wpt)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g crptm6=1-(normprob(wpt[_n-6])-normprob(wpt)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g crptm7=1-(normprob(wpt[_n-7])-normprob(wpt)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g crptm8=1-(normprob(wpt[_n-8])-normprob(wpt)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g crptm9=1-(normprob(wpt[_n-9])-normprob(wpt)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g crptm10=1-(normprob(wpt[_n-10])-normprob(wpt)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g crptm11=1-(normprob(wpt[_n-11])-normprob(wpt)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g crptm12=1-(normprob(wpt[_n-12])-normprob(wpt)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g crptm13=1-(normprob(wpt[_n-13])-normprob(wpt)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g crptm14=1-(normprob(wpt[_n-14])-normprob(wpt)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g crptm15=1-(normprob(wpt[_n-15])-normprob(wpt)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g crptm16=1-(normprob(wpt[_n-16])-normprob(wpt)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g crptm17=1-(normprob(wpt[_n-17])-normprob(wpt)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g crptm18=1-(normprob(wpt[_n-18])-normprob(wpt)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g crptm19=1-(normprob(wpt[_n-19])-normprob(wpt)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g crptm20=1-(normprob(wpt[_n-20])-normprob(wpt)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g crptm21=1-(normprob(wpt[_n-21])-normprob(wpt)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g crptp1=1-(normprob(wpt[_n+1])-normprob(wpt)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g crptp2=1-(normprob(wpt[_n+2])-normprob(wpt)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g crptp3=1-(normprob(wpt[_n+3])-normprob(wpt)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g crptp4=1-(normprob(wpt[_n+4])-normprob(wpt)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g crptp5=1-(normprob(wpt[_n+5])-normprob(wpt)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g crptp6=1-(normprob(wpt[_n+6])-normprob(wpt)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g crptp7=1-(normprob(wpt[_n+7])-normprob(wpt)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g crptp8=1-(normprob(wpt[_n+8])-normprob(wpt)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g crptp9=1-(normprob(wpt[_n+9])-normprob(wpt)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g crptp10=1-(normprob(wpt[_n+10])-normprob(wpt)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g crptp11=1-(normprob(wpt[_n+11])-normprob(wpt)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g crptp12=1-(normprob(wpt[_n+12])-normprob(wpt)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g crptp13=1-(normprob(wpt[_n+13])-normprob(wpt)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g crptp14=1-(normprob(wpt[_n+14])-normprob(wpt)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g crptp15=1-(normprob(wpt[_n+15])-normprob(wpt)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g crptp16=1-(normprob(wpt[_n+16])-normprob(wpt)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g crptp17=1-(normprob(wpt[_n+17])-normprob(wpt)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g crptp18=1-(normprob(wpt[_n+18])-normprob(wpt)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g crptp19=1-(normprob(wpt[_n+19])-normprob(wpt)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g crptp20=1-(normprob(wpt[_n+20])-normprob(wpt)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g crptp21=1-(normprob(wpt[_n+21])-normprob(wpt)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswpt=0

quietly replace criswpt=criswpt+crptm1 if crptm1~=.
quietly replace criswpt=criswpt+crptm2 if crptm2~=.
quietly replace criswpt=criswpt+crptm3 if crptm3~=.
quietly replace criswpt=criswpt+crptm4 if crptm4~=.
quietly replace criswpt=criswpt+crptm5 if crptm5~=.
quietly replace criswpt=criswpt+crptm6 if crptm6~=.
quietly replace criswpt=criswpt+crptm7 if crptm7~=.
quietly replace criswpt=criswpt+crptm8 if crptm8~=.
quietly replace criswpt=criswpt+crptm9 if crptm9~=.
quietly replace criswpt=criswpt+crptm10 if crptm10~=.
quietly replace criswpt=criswpt+crptm11 if crptm11~=.
quietly replace criswpt=criswpt+crptm12 if crptm12~=.
quietly replace criswpt=criswpt+crptm13 if crptm13~=.
quietly replace criswpt=criswpt+crptm14 if crptm14~=.
quietly replace criswpt=criswpt+crptm15 if crptm15~=.
quietly replace criswpt=criswpt+crptm16 if crptm16~=.
quietly replace criswpt=criswpt+crptm17 if crptm17~=.
quietly replace criswpt=criswpt+crptm18 if crptm18~=.
quietly replace criswpt=criswpt+crptm19 if crptm19~=.
quietly replace criswpt=criswpt+crptm20 if crptm20~=.
quietly replace criswpt=criswpt+crptm21 if crptm21~=.
quietly replace criswpt=criswpt+crptp1 if crptp1~=.
quietly replace criswpt=criswpt+crptp2 if crptp2~=.
quietly replace criswpt=criswpt+crptp3 if crptp3~=.
quietly replace criswpt=criswpt+crptp4 if crptp4~=.
quietly replace criswpt=criswpt+crptp5 if crptp5~=.
quietly replace criswpt=criswpt+crptp6 if crptp6~=.
quietly replace criswpt=criswpt+crptp7 if crptp7~=.
quietly replace criswpt=criswpt+crptp8 if crptp8~=.
quietly replace criswpt=criswpt+crptp9 if crptp9~=.
quietly replace criswpt=criswpt+crptp10 if crptp10~=.
quietly replace criswpt=criswpt+crptp11 if crptp11~=.
quietly replace criswpt=criswpt+crptp12 if crptp12~=.
quietly replace criswpt=criswpt+crptp13 if crptp13~=.
quietly replace criswpt=criswpt+crptp14 if crptp14~=.
quietly replace criswpt=criswpt+crptp15 if crptp15~=.
quietly replace criswpt=criswpt+crptp16 if crptp16~=.
quietly replace criswpt=criswpt+crptp17 if crptp17~=.
quietly replace criswpt=criswpt+crptp18 if crptp18~=.
quietly replace criswpt=criswpt+crptp19 if crptp19~=.
quietly replace criswpt=criswpt+crptp20 if crptp20~=.
quietly replace criswpt=criswpt+crptp21 if crptp21~=.

drop crptm1-crptm21
drop crptp1-crptp21
*
* The variable is y, the averaging is done via method t
*
quietly g crytm1=1-(normprob(wyt[_n-1])-normprob(wyt)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g crytm2=1-(normprob(wyt[_n-2])-normprob(wyt)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g crytm3=1-(normprob(wyt[_n-3])-normprob(wyt)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g crytm4=1-(normprob(wyt[_n-4])-normprob(wyt)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g crytm5=1-(normprob(wyt[_n-5])-normprob(wyt)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g crytm6=1-(normprob(wyt[_n-6])-normprob(wyt)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g crytm7=1-(normprob(wyt[_n-7])-normprob(wyt)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g crytm8=1-(normprob(wyt[_n-8])-normprob(wyt)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g crytm9=1-(normprob(wyt[_n-9])-normprob(wyt)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g crytm10=1-(normprob(wyt[_n-10])-normprob(wyt)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g crytm11=1-(normprob(wyt[_n-11])-normprob(wyt)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g crytm12=1-(normprob(wyt[_n-12])-normprob(wyt)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g crytm13=1-(normprob(wyt[_n-13])-normprob(wyt)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g crytm14=1-(normprob(wyt[_n-14])-normprob(wyt)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g crytm15=1-(normprob(wyt[_n-15])-normprob(wyt)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g crytm16=1-(normprob(wyt[_n-16])-normprob(wyt)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g crytm17=1-(normprob(wyt[_n-17])-normprob(wyt)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g crytm18=1-(normprob(wyt[_n-18])-normprob(wyt)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g crytm19=1-(normprob(wyt[_n-19])-normprob(wyt)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g crytm20=1-(normprob(wyt[_n-20])-normprob(wyt)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g crytm21=1-(normprob(wyt[_n-21])-normprob(wyt)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g crytp1=1-(normprob(wyt[_n+1])-normprob(wyt)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g crytp2=1-(normprob(wyt[_n+2])-normprob(wyt)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g crytp3=1-(normprob(wyt[_n+3])-normprob(wyt)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g crytp4=1-(normprob(wyt[_n+4])-normprob(wyt)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g crytp5=1-(normprob(wyt[_n+5])-normprob(wyt)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g crytp6=1-(normprob(wyt[_n+6])-normprob(wyt)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g crytp7=1-(normprob(wyt[_n+7])-normprob(wyt)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g crytp8=1-(normprob(wyt[_n+8])-normprob(wyt)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g crytp9=1-(normprob(wyt[_n+9])-normprob(wyt)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g crytp10=1-(normprob(wyt[_n+10])-normprob(wyt)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g crytp11=1-(normprob(wyt[_n+11])-normprob(wyt)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g crytp12=1-(normprob(wyt[_n+12])-normprob(wyt)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g crytp13=1-(normprob(wyt[_n+13])-normprob(wyt)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g crytp14=1-(normprob(wyt[_n+14])-normprob(wyt)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g crytp15=1-(normprob(wyt[_n+15])-normprob(wyt)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g crytp16=1-(normprob(wyt[_n+16])-normprob(wyt)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g crytp17=1-(normprob(wyt[_n+17])-normprob(wyt)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g crytp18=1-(normprob(wyt[_n+18])-normprob(wyt)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g crytp19=1-(normprob(wyt[_n+19])-normprob(wyt)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g crytp20=1-(normprob(wyt[_n+20])-normprob(wyt)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g crytp21=1-(normprob(wyt[_n+21])-normprob(wyt)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswyt=0

quietly replace criswyt=criswyt+crytm1 if crytm1~=.
quietly replace criswyt=criswyt+crytm2 if crytm2~=.
quietly replace criswyt=criswyt+crytm3 if crytm3~=.
quietly replace criswyt=criswyt+crytm4 if crytm4~=.
quietly replace criswyt=criswyt+crytm5 if crytm5~=.
quietly replace criswyt=criswyt+crytm6 if crytm6~=.
quietly replace criswyt=criswyt+crytm7 if crytm7~=.
quietly replace criswyt=criswyt+crytm8 if crytm8~=.
quietly replace criswyt=criswyt+crytm9 if crytm9~=.
quietly replace criswyt=criswyt+crytm10 if crytm10~=.
quietly replace criswyt=criswyt+crytm11 if crytm11~=.
quietly replace criswyt=criswyt+crytm12 if crytm12~=.
quietly replace criswyt=criswyt+crytm13 if crytm13~=.
quietly replace criswyt=criswyt+crytm14 if crytm14~=.
quietly replace criswyt=criswyt+crytm15 if crytm15~=.
quietly replace criswyt=criswyt+crytm16 if crytm16~=.
quietly replace criswyt=criswyt+crytm17 if crytm17~=.
quietly replace criswyt=criswyt+crytm18 if crytm18~=.
quietly replace criswyt=criswyt+crytm19 if crytm19~=.
quietly replace criswyt=criswyt+crytm20 if crytm20~=.
quietly replace criswyt=criswyt+crytm21 if crytm21~=.
quietly replace criswyt=criswyt+crytp1 if crytp1~=.
quietly replace criswyt=criswyt+crytp2 if crytp2~=.
quietly replace criswyt=criswyt+crytp3 if crytp3~=.
quietly replace criswyt=criswyt+crytp4 if crytp4~=.
quietly replace criswyt=criswyt+crytp5 if crytp5~=.
quietly replace criswyt=criswyt+crytp6 if crytp6~=.
quietly replace criswyt=criswyt+crytp7 if crytp7~=.
quietly replace criswyt=criswyt+crytp8 if crytp8~=.
quietly replace criswyt=criswyt+crytp9 if crytp9~=.
quietly replace criswyt=criswyt+crytp10 if crytp10~=.
quietly replace criswyt=criswyt+crytp11 if crytp11~=.
quietly replace criswyt=criswyt+crytp12 if crytp12~=.
quietly replace criswyt=criswyt+crytp13 if crytp13~=.
quietly replace criswyt=criswyt+crytp14 if crytp14~=.
quietly replace criswyt=criswyt+crytp15 if crytp15~=.
quietly replace criswyt=criswyt+crytp16 if crytp16~=.
quietly replace criswyt=criswyt+crytp17 if crytp17~=.
quietly replace criswyt=criswyt+crytp18 if crytp18~=.
quietly replace criswyt=criswyt+crytp19 if crytp19~=.
quietly replace criswyt=criswyt+crytp20 if crytp20~=.
quietly replace criswyt=criswyt+crytp21 if crytp21~=.

drop crytm1-crytm21
drop crytp1-crytp21
*
* The variable is u, the averaging is done via method t
*
quietly g crutm1=1-(normprob(wut[_n-1])-normprob(wut)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g crutm2=1-(normprob(wut[_n-2])-normprob(wut)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g crutm3=1-(normprob(wut[_n-3])-normprob(wut)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g crutm4=1-(normprob(wut[_n-4])-normprob(wut)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g crutm5=1-(normprob(wut[_n-5])-normprob(wut)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g crutm6=1-(normprob(wut[_n-6])-normprob(wut)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g crutm7=1-(normprob(wut[_n-7])-normprob(wut)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g crutm8=1-(normprob(wut[_n-8])-normprob(wut)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g crutm9=1-(normprob(wut[_n-9])-normprob(wut)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g crutm10=1-(normprob(wut[_n-10])-normprob(wut)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g crutm11=1-(normprob(wut[_n-11])-normprob(wut)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g crutm12=1-(normprob(wut[_n-12])-normprob(wut)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g crutm13=1-(normprob(wut[_n-13])-normprob(wut)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g crutm14=1-(normprob(wut[_n-14])-normprob(wut)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g crutm15=1-(normprob(wut[_n-15])-normprob(wut)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g crutm16=1-(normprob(wut[_n-16])-normprob(wut)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g crutm17=1-(normprob(wut[_n-17])-normprob(wut)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g crutm18=1-(normprob(wut[_n-18])-normprob(wut)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g crutm19=1-(normprob(wut[_n-19])-normprob(wut)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g crutm20=1-(normprob(wut[_n-20])-normprob(wut)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g crutm21=1-(normprob(wut[_n-21])-normprob(wut)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g crutp1=1-(normprob(wut[_n+1])-normprob(wut)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g crutp2=1-(normprob(wut[_n+2])-normprob(wut)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g crutp3=1-(normprob(wut[_n+3])-normprob(wut)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g crutp4=1-(normprob(wut[_n+4])-normprob(wut)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g crutp5=1-(normprob(wut[_n+5])-normprob(wut)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g crutp6=1-(normprob(wut[_n+6])-normprob(wut)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g crutp7=1-(normprob(wut[_n+7])-normprob(wut)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g crutp8=1-(normprob(wut[_n+8])-normprob(wut)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g crutp9=1-(normprob(wut[_n+9])-normprob(wut)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g crutp10=1-(normprob(wut[_n+10])-normprob(wut)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g crutp11=1-(normprob(wut[_n+11])-normprob(wut)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g crutp12=1-(normprob(wut[_n+12])-normprob(wut)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g crutp13=1-(normprob(wut[_n+13])-normprob(wut)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g crutp14=1-(normprob(wut[_n+14])-normprob(wut)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g crutp15=1-(normprob(wut[_n+15])-normprob(wut)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g crutp16=1-(normprob(wut[_n+16])-normprob(wut)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g crutp17=1-(normprob(wut[_n+17])-normprob(wut)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g crutp18=1-(normprob(wut[_n+18])-normprob(wut)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g crutp19=1-(normprob(wut[_n+19])-normprob(wut)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g crutp20=1-(normprob(wut[_n+20])-normprob(wut)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g crutp21=1-(normprob(wut[_n+21])-normprob(wut)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswut=0

quietly replace criswut=criswut+crutm1 if crutm1~=.
quietly replace criswut=criswut+crutm2 if crutm2~=.
quietly replace criswut=criswut+crutm3 if crutm3~=.
quietly replace criswut=criswut+crutm4 if crutm4~=.
quietly replace criswut=criswut+crutm5 if crutm5~=.
quietly replace criswut=criswut+crutm6 if crutm6~=.
quietly replace criswut=criswut+crutm7 if crutm7~=.
quietly replace criswut=criswut+crutm8 if crutm8~=.
quietly replace criswut=criswut+crutm9 if crutm9~=.
quietly replace criswut=criswut+crutm10 if crutm10~=.
quietly replace criswut=criswut+crutm11 if crutm11~=.
quietly replace criswut=criswut+crutm12 if crutm12~=.
quietly replace criswut=criswut+crutm13 if crutm13~=.
quietly replace criswut=criswut+crutm14 if crutm14~=.
quietly replace criswut=criswut+crutm15 if crutm15~=.
quietly replace criswut=criswut+crutm16 if crutm16~=.
quietly replace criswut=criswut+crutm17 if crutm17~=.
quietly replace criswut=criswut+crutm18 if crutm18~=.
quietly replace criswut=criswut+crutm19 if crutm19~=.
quietly replace criswut=criswut+crutm20 if crutm20~=.
quietly replace criswut=criswut+crutm21 if crutm21~=.
quietly replace criswut=criswut+crutp1 if crutp1~=.
quietly replace criswut=criswut+crutp2 if crutp2~=.
quietly replace criswut=criswut+crutp3 if crutp3~=.
quietly replace criswut=criswut+crutp4 if crutp4~=.
quietly replace criswut=criswut+crutp5 if crutp5~=.
quietly replace criswut=criswut+crutp6 if crutp6~=.
quietly replace criswut=criswut+crutp7 if crutp7~=.
quietly replace criswut=criswut+crutp8 if crutp8~=.
quietly replace criswut=criswut+crutp9 if crutp9~=.
quietly replace criswut=criswut+crutp10 if crutp10~=.
quietly replace criswut=criswut+crutp11 if crutp11~=.
quietly replace criswut=criswut+crutp12 if crutp12~=.
quietly replace criswut=criswut+crutp13 if crutp13~=.
quietly replace criswut=criswut+crutp14 if crutp14~=.
quietly replace criswut=criswut+crutp15 if crutp15~=.
quietly replace criswut=criswut+crutp16 if crutp16~=.
quietly replace criswut=criswut+crutp17 if crutp17~=.
quietly replace criswut=criswut+crutp18 if crutp18~=.
quietly replace criswut=criswut+crutp19 if crutp19~=.
quietly replace criswut=criswut+crutp20 if crutp20~=.
quietly replace criswut=criswut+crutp21 if crutp21~=.

drop crutm1-crutm21
drop crutp1-crutp21
*
* The variable is t, the averaging is done via method t
*
quietly g crttm1=1-(normprob(wtt[_n-1])-normprob(wtt)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g crttm2=1-(normprob(wtt[_n-2])-normprob(wtt)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g crttm3=1-(normprob(wtt[_n-3])-normprob(wtt)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g crttm4=1-(normprob(wtt[_n-4])-normprob(wtt)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g crttm5=1-(normprob(wtt[_n-5])-normprob(wtt)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g crttm6=1-(normprob(wtt[_n-6])-normprob(wtt)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g crttm7=1-(normprob(wtt[_n-7])-normprob(wtt)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g crttm8=1-(normprob(wtt[_n-8])-normprob(wtt)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g crttm9=1-(normprob(wtt[_n-9])-normprob(wtt)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g crttm10=1-(normprob(wtt[_n-10])-normprob(wtt)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g crttm11=1-(normprob(wtt[_n-11])-normprob(wtt)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g crttm12=1-(normprob(wtt[_n-12])-normprob(wtt)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g crttm13=1-(normprob(wtt[_n-13])-normprob(wtt)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g crttm14=1-(normprob(wtt[_n-14])-normprob(wtt)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g crttm15=1-(normprob(wtt[_n-15])-normprob(wtt)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g crttm16=1-(normprob(wtt[_n-16])-normprob(wtt)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g crttm17=1-(normprob(wtt[_n-17])-normprob(wtt)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g crttm18=1-(normprob(wtt[_n-18])-normprob(wtt)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g crttm19=1-(normprob(wtt[_n-19])-normprob(wtt)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g crttm20=1-(normprob(wtt[_n-20])-normprob(wtt)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g crttm21=1-(normprob(wtt[_n-21])-normprob(wtt)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g crttp1=1-(normprob(wtt[_n+1])-normprob(wtt)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g crttp2=1-(normprob(wtt[_n+2])-normprob(wtt)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g crttp3=1-(normprob(wtt[_n+3])-normprob(wtt)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g crttp4=1-(normprob(wtt[_n+4])-normprob(wtt)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g crttp5=1-(normprob(wtt[_n+5])-normprob(wtt)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g crttp6=1-(normprob(wtt[_n+6])-normprob(wtt)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g crttp7=1-(normprob(wtt[_n+7])-normprob(wtt)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g crttp8=1-(normprob(wtt[_n+8])-normprob(wtt)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g crttp9=1-(normprob(wtt[_n+9])-normprob(wtt)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g crttp10=1-(normprob(wtt[_n+10])-normprob(wtt)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g crttp11=1-(normprob(wtt[_n+11])-normprob(wtt)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g crttp12=1-(normprob(wtt[_n+12])-normprob(wtt)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g crttp13=1-(normprob(wtt[_n+13])-normprob(wtt)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g crttp14=1-(normprob(wtt[_n+14])-normprob(wtt)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g crttp15=1-(normprob(wtt[_n+15])-normprob(wtt)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g crttp16=1-(normprob(wtt[_n+16])-normprob(wtt)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g crttp17=1-(normprob(wtt[_n+17])-normprob(wtt)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g crttp18=1-(normprob(wtt[_n+18])-normprob(wtt)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g crttp19=1-(normprob(wtt[_n+19])-normprob(wtt)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g crttp20=1-(normprob(wtt[_n+20])-normprob(wtt)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g crttp21=1-(normprob(wtt[_n+21])-normprob(wtt)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswtt=0

quietly replace criswtt=criswtt+crttm1 if crttm1~=.
quietly replace criswtt=criswtt+crttm2 if crttm2~=.
quietly replace criswtt=criswtt+crttm3 if crttm3~=.
quietly replace criswtt=criswtt+crttm4 if crttm4~=.
quietly replace criswtt=criswtt+crttm5 if crttm5~=.
quietly replace criswtt=criswtt+crttm6 if crttm6~=.
quietly replace criswtt=criswtt+crttm7 if crttm7~=.
quietly replace criswtt=criswtt+crttm8 if crttm8~=.
quietly replace criswtt=criswtt+crttm9 if crttm9~=.
quietly replace criswtt=criswtt+crttm10 if crttm10~=.
quietly replace criswtt=criswtt+crttm11 if crttm11~=.
quietly replace criswtt=criswtt+crttm12 if crttm12~=.
quietly replace criswtt=criswtt+crttm13 if crttm13~=.
quietly replace criswtt=criswtt+crttm14 if crttm14~=.
quietly replace criswtt=criswtt+crttm15 if crttm15~=.
quietly replace criswtt=criswtt+crttm16 if crttm16~=.
quietly replace criswtt=criswtt+crttm17 if crttm17~=.
quietly replace criswtt=criswtt+crttm18 if crttm18~=.
quietly replace criswtt=criswtt+crttm19 if crttm19~=.
quietly replace criswtt=criswtt+crttm20 if crttm20~=.
quietly replace criswtt=criswtt+crttm21 if crttm21~=.
quietly replace criswtt=criswtt+crttp1 if crttp1~=.
quietly replace criswtt=criswtt+crttp2 if crttp2~=.
quietly replace criswtt=criswtt+crttp3 if crttp3~=.
quietly replace criswtt=criswtt+crttp4 if crttp4~=.
quietly replace criswtt=criswtt+crttp5 if crttp5~=.
quietly replace criswtt=criswtt+crttp6 if crttp6~=.
quietly replace criswtt=criswtt+crttp7 if crttp7~=.
quietly replace criswtt=criswtt+crttp8 if crttp8~=.
quietly replace criswtt=criswtt+crttp9 if crttp9~=.
quietly replace criswtt=criswtt+crttp10 if crttp10~=.
quietly replace criswtt=criswtt+crttp11 if crttp11~=.
quietly replace criswtt=criswtt+crttp12 if crttp12~=.
quietly replace criswtt=criswtt+crttp13 if crttp13~=.
quietly replace criswtt=criswtt+crttp14 if crttp14~=.
quietly replace criswtt=criswtt+crttp15 if crttp15~=.
quietly replace criswtt=criswtt+crttp16 if crttp16~=.
quietly replace criswtt=criswtt+crttp17 if crttp17~=.
quietly replace criswtt=criswtt+crttp18 if crttp18~=.
quietly replace criswtt=criswtt+crttp19 if crttp19~=.
quietly replace criswtt=criswtt+crttp20 if crttp20~=.
quietly replace criswtt=criswtt+crttp21 if crttp21~=.

drop crttm1-crttm21
drop crttp1-crttp21
*
* The variable is b, the averaging is done via method t
*
quietly g crbtm1=1-(normprob(wbt[_n-1])-normprob(wbt)) if (crisis[_n-1]==1)&(ifscode~=ifscode[_n-1]&date10==date10[_n-1])
quietly g crbtm2=1-(normprob(wbt[_n-2])-normprob(wbt)) if (crisis[_n-2]==1)&(ifscode~=ifscode[_n-2]&date10==date10[_n-2])
quietly g crbtm3=1-(normprob(wbt[_n-3])-normprob(wbt)) if (crisis[_n-3]==1)&(ifscode~=ifscode[_n-3]&date10==date10[_n-3])
quietly g crbtm4=1-(normprob(wbt[_n-4])-normprob(wbt)) if (crisis[_n-4]==1)&(ifscode~=ifscode[_n-4]&date10==date10[_n-4])
quietly g crbtm5=1-(normprob(wbt[_n-5])-normprob(wbt)) if (crisis[_n-5]==1)&(ifscode~=ifscode[_n-5]&date10==date10[_n-5])
quietly g crbtm6=1-(normprob(wbt[_n-6])-normprob(wbt)) if (crisis[_n-6]==1)&(ifscode~=ifscode[_n-6]&date10==date10[_n-6])
quietly g crbtm7=1-(normprob(wbt[_n-7])-normprob(wbt)) if (crisis[_n-7]==1)&(ifscode~=ifscode[_n-7]&date10==date10[_n-7])
quietly g crbtm8=1-(normprob(wbt[_n-8])-normprob(wbt)) if (crisis[_n-8]==1)&(ifscode~=ifscode[_n-8]&date10==date10[_n-8])
quietly g crbtm9=1-(normprob(wbt[_n-9])-normprob(wbt)) if (crisis[_n-9]==1)&(ifscode~=ifscode[_n-9]&date10==date10[_n-9])
quietly g crbtm10=1-(normprob(wbt[_n-10])-normprob(wbt)) if (crisis[_n-10]==1)&(ifscode~=ifscode[_n-10]&date10==date10[_n-10])
quietly g crbtm11=1-(normprob(wbt[_n-11])-normprob(wbt)) if (crisis[_n-11]==1)&(ifscode~=ifscode[_n-11]&date10==date10[_n-11])
quietly g crbtm12=1-(normprob(wbt[_n-12])-normprob(wbt)) if (crisis[_n-12]==1)&(ifscode~=ifscode[_n-12]&date10==date10[_n-12])
quietly g crbtm13=1-(normprob(wbt[_n-13])-normprob(wbt)) if (crisis[_n-13]==1)&(ifscode~=ifscode[_n-13]&date10==date10[_n-13])
quietly g crbtm14=1-(normprob(wbt[_n-14])-normprob(wbt)) if (crisis[_n-14]==1)&(ifscode~=ifscode[_n-14]&date10==date10[_n-14])
quietly g crbtm15=1-(normprob(wbt[_n-15])-normprob(wbt)) if (crisis[_n-15]==1)&(ifscode~=ifscode[_n-15]&date10==date10[_n-15])
quietly g crbtm16=1-(normprob(wbt[_n-16])-normprob(wbt)) if (crisis[_n-16]==1)&(ifscode~=ifscode[_n-16]&date10==date10[_n-16])
quietly g crbtm17=1-(normprob(wbt[_n-17])-normprob(wbt)) if (crisis[_n-17]==1)&(ifscode~=ifscode[_n-17]&date10==date10[_n-17])
quietly g crbtm18=1-(normprob(wbt[_n-18])-normprob(wbt)) if (crisis[_n-18]==1)&(ifscode~=ifscode[_n-18]&date10==date10[_n-18])
quietly g crbtm19=1-(normprob(wbt[_n-19])-normprob(wbt)) if (crisis[_n-19]==1)&(ifscode~=ifscode[_n-19]&date10==date10[_n-19])
quietly g crbtm20=1-(normprob(wbt[_n-20])-normprob(wbt)) if (crisis[_n-20]==1)&(ifscode~=ifscode[_n-20]&date10==date10[_n-20])
quietly g crbtm21=1-(normprob(wbt[_n-21])-normprob(wbt)) if (crisis[_n-21]==1)&(ifscode~=ifscode[_n-21]&date10==date10[_n-21])

quietly g crbtp1=1-(normprob(wbt[_n+1])-normprob(wbt)) if (crisis[_n+1]==1)&(ifscode~=ifscode[_n+1]&date10==date10[_n+1])
quietly g crbtp2=1-(normprob(wbt[_n+2])-normprob(wbt)) if (crisis[_n+2]==1)&(ifscode~=ifscode[_n+2]&date10==date10[_n+2])
quietly g crbtp3=1-(normprob(wbt[_n+3])-normprob(wbt)) if (crisis[_n+3]==1)&(ifscode~=ifscode[_n+3]&date10==date10[_n+3])
quietly g crbtp4=1-(normprob(wbt[_n+4])-normprob(wbt)) if (crisis[_n+4]==1)&(ifscode~=ifscode[_n+4]&date10==date10[_n+4])
quietly g crbtp5=1-(normprob(wbt[_n+5])-normprob(wbt)) if (crisis[_n+5]==1)&(ifscode~=ifscode[_n+5]&date10==date10[_n+5])
quietly g crbtp6=1-(normprob(wbt[_n+6])-normprob(wbt)) if (crisis[_n+6]==1)&(ifscode~=ifscode[_n+6]&date10==date10[_n+6])
quietly g crbtp7=1-(normprob(wbt[_n+7])-normprob(wbt)) if (crisis[_n+7]==1)&(ifscode~=ifscode[_n+7]&date10==date10[_n+7])
quietly g crbtp8=1-(normprob(wbt[_n+8])-normprob(wbt)) if (crisis[_n+8]==1)&(ifscode~=ifscode[_n+8]&date10==date10[_n+8])
quietly g crbtp9=1-(normprob(wbt[_n+9])-normprob(wbt)) if (crisis[_n+9]==1)&(ifscode~=ifscode[_n+9]&date10==date10[_n+9])
quietly g crbtp10=1-(normprob(wbt[_n+10])-normprob(wbt)) if (crisis[_n+10]==1)&(ifscode~=ifscode[_n+10]&date10==date10[_n+10])
quietly g crbtp11=1-(normprob(wbt[_n+11])-normprob(wbt)) if (crisis[_n+11]==1)&(ifscode~=ifscode[_n+11]&date10==date10[_n+11])
quietly g crbtp12=1-(normprob(wbt[_n+12])-normprob(wbt)) if (crisis[_n+12]==1)&(ifscode~=ifscode[_n+12]&date10==date10[_n+12])
quietly g crbtp13=1-(normprob(wbt[_n+13])-normprob(wbt)) if (crisis[_n+13]==1)&(ifscode~=ifscode[_n+13]&date10==date10[_n+13])
quietly g crbtp14=1-(normprob(wbt[_n+14])-normprob(wbt)) if (crisis[_n+14]==1)&(ifscode~=ifscode[_n+14]&date10==date10[_n+14])
quietly g crbtp15=1-(normprob(wbt[_n+15])-normprob(wbt)) if (crisis[_n+15]==1)&(ifscode~=ifscode[_n+15]&date10==date10[_n+15])
quietly g crbtp16=1-(normprob(wbt[_n+16])-normprob(wbt)) if (crisis[_n+16]==1)&(ifscode~=ifscode[_n+16]&date10==date10[_n+16])
quietly g crbtp17=1-(normprob(wbt[_n+17])-normprob(wbt)) if (crisis[_n+17]==1)&(ifscode~=ifscode[_n+17]&date10==date10[_n+17])
quietly g crbtp18=1-(normprob(wbt[_n+18])-normprob(wbt)) if (crisis[_n+18]==1)&(ifscode~=ifscode[_n+18]&date10==date10[_n+18])
quietly g crbtp19=1-(normprob(wbt[_n+19])-normprob(wbt)) if (crisis[_n+19]==1)&(ifscode~=ifscode[_n+19]&date10==date10[_n+19])
quietly g crbtp20=1-(normprob(wbt[_n+20])-normprob(wbt)) if (crisis[_n+20]==1)&(ifscode~=ifscode[_n+20]&date10==date10[_n+20])
quietly g crbtp21=1-(normprob(wbt[_n+21])-normprob(wbt)) if (crisis[_n+21]==1)&(ifscode~=ifscode[_n+21]&date10==date10[_n+21])

quietly g criswbt=0

quietly replace criswbt=criswbt+crbtm1 if crbtm1~=.
quietly replace criswbt=criswbt+crbtm2 if crbtm2~=.
quietly replace criswbt=criswbt+crbtm3 if crbtm3~=.
quietly replace criswbt=criswbt+crbtm4 if crbtm4~=.
quietly replace criswbt=criswbt+crbtm5 if crbtm5~=.
quietly replace criswbt=criswbt+crbtm6 if crbtm6~=.
quietly replace criswbt=criswbt+crbtm7 if crbtm7~=.
quietly replace criswbt=criswbt+crbtm8 if crbtm8~=.
quietly replace criswbt=criswbt+crbtm9 if crbtm9~=.
quietly replace criswbt=criswbt+crbtm10 if crbtm10~=.
quietly replace criswbt=criswbt+crbtm11 if crbtm11~=.
quietly replace criswbt=criswbt+crbtm12 if crbtm12~=.
quietly replace criswbt=criswbt+crbtm13 if crbtm13~=.
quietly replace criswbt=criswbt+crbtm14 if crbtm14~=.
quietly replace criswbt=criswbt+crbtm15 if crbtm15~=.
quietly replace criswbt=criswbt+crbtm16 if crbtm16~=.
quietly replace criswbt=criswbt+crbtm17 if crbtm17~=.
quietly replace criswbt=criswbt+crbtm18 if crbtm18~=.
quietly replace criswbt=criswbt+crbtm19 if crbtm19~=.
quietly replace criswbt=criswbt+crbtm20 if crbtm20~=.
quietly replace criswbt=criswbt+crbtm21 if crbtm21~=.
quietly replace criswbt=criswbt+crbtp1 if crbtp1~=.
quietly replace criswbt=criswbt+crbtp2 if crbtp2~=.
quietly replace criswbt=criswbt+crbtp3 if crbtp3~=.
quietly replace criswbt=criswbt+crbtp4 if crbtp4~=.
quietly replace criswbt=criswbt+crbtp5 if crbtp5~=.
quietly replace criswbt=criswbt+crbtp6 if crbtp6~=.
quietly replace criswbt=criswbt+crbtp7 if crbtp7~=.
quietly replace criswbt=criswbt+crbtp8 if crbtp8~=.
quietly replace criswbt=criswbt+crbtp9 if crbtp9~=.
quietly replace criswbt=criswbt+crbtp10 if crbtp10~=.
quietly replace criswbt=criswbt+crbtp11 if crbtp11~=.
quietly replace criswbt=criswbt+crbtp12 if crbtp12~=.
quietly replace criswbt=criswbt+crbtp13 if crbtp13~=.
quietly replace criswbt=criswbt+crbtp14 if crbtp14~=.
quietly replace criswbt=criswbt+crbtp15 if crbtp15~=.
quietly replace criswbt=criswbt+crbtp16 if crbtp16~=.
quietly replace criswbt=criswbt+crbtp17 if crbtp17~=.
quietly replace criswbt=criswbt+crbtp18 if crbtp18~=.
quietly replace criswbt=criswbt+crbtp19 if crbtp19~=.
quietly replace criswbt=criswbt+crbtp20 if crbtp20~=.
quietly replace criswbt=criswbt+crbtp21 if crbtp21~=.

drop crbtm1-crbtm21
drop crbtp1-crbtp21

*
* Now perform the factor analysis to reduce the dimensoionality of the
* macro-similarity variables
*
factor criswci criswmi criswpi criswyi criswui criswti criswbi, factors(1)
score criswi
replace criswi=0 if ((criswci==0&criswmi==0)&(criswpi==0&criswyi==0))&((criswui==0&criswti==0)&(criswbi==0))
factor criswct criswmt criswpt criswyt criswut criswtt criswbt, factors(1)
score criswt
replace criswt=0 if ((criswct==0&criswmt==0)&(criswpt==0&criswyt==0))&((criswut==0&criswtt==0)&(criswbt==0))
*
* Now add in the factor of macro contagion terms (cross-sectional first)
*
* Regressors are only contemporaneous, the contagion term is contemp
*
dprobit crisis crisiso crisisw criswi ka govtvict govtloss dlcredit dlprice dlrealy dlemploy dunr dbudget dcacc
test crisiso crisisw criswi
*
* Regressors have 2 lags, the contagion term is contemp
*
dprobit crisis crisiso crisisw criswi kalg2 gv2lag gl2lag lag2crd lag2pri lag2rly lag2emp lag2unr lag2bud lag2cac
test crisiso crisisw criswi
*
* Regressors are contemporaneous and 8-lagged, the contagion term is contemp
*
dprobit crisis crisiso crisisw criswi c8ka c8gv c8gl c8crd c8pri c8rly c8emp c8unr c8bud c8cac
test crisiso crisisw criswi
*
* Now add in the whole vector of macro contagion terms (time-series now)
*
* Regressors are only contemporaneous, the contagion term is contemp
*
dprobit crisis crisiso crisisw criswt ka govtvict govtloss dlcredit dlprice dlrealy dlemploy dunr dbudget dcacc
test crisiso crisisw criswt
*
* Regressors have 2 lags, the contagion term is contemp
*
dprobit crisis crisiso crisisw criswt kalg2 gv2lag gl2lag lag2crd lag2pri lag2rly lag2emp lag2unr lag2bud lag2cac
test crisiso crisisw criswt
*
* Regressors are contemporaneous and 8-lagged, the contagion term is contemp
*
dprobit crisis crisiso crisisw criswt c8ka c8gv c8gl c8crd c8pri c8rly c8emp c8unr c8bud c8cac
test crisiso crisisw criswt
*
* Finish up
*
drop _all
log close
exit,clear
